@@ -54,8 +54,16 @@ _DOWNLOAD_URL = "http://opihi.cs.uvic.ca/sound/genres.tar.gz"
 _HOMEPAGE_URL = "http://marsyas.info/index.html"
 
 _CLASS_LABELS = [
-    "blues", "classical", "country", "disco", "hiphop", "jazz", "metal", "pop",
-    "reggae", "rock"
+    "blues",
+    "classical",
+    "country",
+    "disco",
+    "hiphop",
+    "jazz",
+    "metal",
+    "pop",
+    "reggae",
+    "rock",
 ]
 
 
@@ -85,7 +93,8 @@ class GTZAN(tfds.core.GeneratorBasedBuilder):
     # There is no predefined train/val/test split for this dataset.
     return [
         tfds.core.SplitGenerator(
-            name=tfds.Split.TRAIN, gen_kwargs={"path": path}),
+            name=tfds.Split.TRAIN, gen_kwargs={"path": path}
+        ),
     ]
 
   def _generate_examples(self, path):
