@@ -25,7 +25,8 @@ from tensorflow_datasets.core.community import huggingface_wrapper
 
 
 def builder_cls_from_module(
-    module_name: str,) -> Type[dataset_builder.DatasetBuilder]:
+    module_name: str,
+) -> Type[dataset_builder.DatasetBuilder]:
   """Imports the module and extract the `tfds.core.DatasetBuilder`.
 
   Args:
@@ -41,8 +42,7 @@ def builder_cls_from_module(
     importlib.invalidate_caches()
 
     # Executing the module will register the datasets in _MODULE_TO_DATASETS.
-    with registered.skip_registration(),\
-         huggingface_wrapper.mock_huggingface_import():
+    with registered.skip_registration(), huggingface_wrapper.mock_huggingface_import():
       importlib.import_module(module_name)
       # TODO(tfds): For community-installed modules, we should raise cleaner
       # error if there is additional missing dependency. E.g. Parsing all
@@ -57,5 +57,6 @@ def builder_cls_from_module(
         'Make sure the module only contains a single `DatasetBuilder`.\n'
         'If no dataset is detected, make sure that all abstractmethods are '
         'implemented.\n'
-        f'Detected builders: {builder_classes}')
+        f'Detected builders: {builder_classes}'
+    )
   return builder_classes[0]
