@@ -1,5 +1,5 @@
 # coding=utf-8
-# Copyright 2021 The TensorFlow Datasets Authors.
+# Copyright 2022 The TensorFlow Datasets Authors.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -22,12 +22,14 @@ from tensorflow_datasets.core.community import load
 
 def test_import():
   builder_cls = load.builder_cls_from_module(
-      'tensorflow_datasets.testing.dummy_dataset.dummy_dataset')
+      'tensorflow_datasets.testing.dummy_dataset.dummy_dataset'
+  )
   assert builder_cls.__name__ == 'DummyDataset'
 
   # Module should have been cached
   builder_cls_2 = load.builder_cls_from_module(
-      'tensorflow_datasets.testing.dummy_dataset.dummy_dataset')
+      'tensorflow_datasets.testing.dummy_dataset.dummy_dataset'
+  )
   assert builder_cls is builder_cls_2
 
   from tensorflow_datasets.testing.dummy_dataset import dummy_dataset  # pylint: disable=g-import-not-at-top
