@@ -22,7 +22,6 @@ from unittest import mock
 
 from absl import flags
 from absl.testing import parameterized
-
 import dill
 from etils import epath
 import numpy as np
@@ -34,6 +33,7 @@ from tensorflow_datasets.core import dataset_info
 from tensorflow_datasets.core import dataset_utils
 from tensorflow_datasets.core import download
 from tensorflow_datasets.core import features
+from tensorflow_datasets.core import file_adapters
 from tensorflow_datasets.core import load
 from tensorflow_datasets.core import naming
 from tensorflow_datasets.core import splits as splits_lib
@@ -140,7 +140,7 @@ year = "2022"
     )
 
 
-class DatasetBuilderTest(testing.TestCase):
+class DatasetBuilderTest(parameterized.TestCase, testing.TestCase):
 
   @classmethod
   def setUpClass(cls):
@@ -160,7 +160,7 @@ class DatasetBuilderTest(testing.TestCase):
           split=splits_lib.Split.TRAIN,
       )
       data = list(dataset_utils.as_numpy(dataset))
-      self.assertEqual(20, len(data))
+      self.assertLen(data, 20)
       self.assertLess(data[0]["x"], 30)
 
   # Disable test until dependency on Riegeli is fixed.
@@ -249,10 +249,10 @@ class DatasetBuilderTest(testing.TestCase):
     )
 
     data = list(dataset_utils.as_numpy(ds_train))
-    self.assertEqual(20, len(data))
+    self.assertLen(data, 20)
 
     data = list(dataset_utils.as_numpy(ds_test))
-    self.assertEqual(10, len(data))
+    self.assertLen(data, 10)
 
   def test_build_data_dir(self):
     with testing.tmp_dir(self.get_temp_dir()) as tmp_dir:
@@ -334,8 +334,8 @@ class DatasetBuilderTest(testing.TestCase):
             for split in splits_list
         ]
 
-        self.assertEqual(20, len(train_data))
-        self.assertEqual(10, len(test_data))
+        self.assertLen(train_data, 20)
+        self.assertLen(test_data, 10)
         self.assertCountEqual(
             [incr + el for el in range(30)], train_data + test_data
         )
@@ -692,56 +692,6 @@ class BuilderPickleTest(testing.TestCase):
     self.assertEqual(builder.version, builder2.version)
 
 
-class BuilderRestoreGcsTest(testing.TestCase):
-
-  def setUp(self):
-    super(BuilderRestoreGcsTest, self).setUp()
-
-    def load_mnist_dataset_info(self):
-      mnist_info_path = os.path.join(
-          utils.tfds_path(),
-          "testing/test_data/dataset_info/mnist/3.0.1",
-      )
-      mnist_info_path = os.path.normpath(mnist_info_path)
-      self.read_from_directory(mnist_info_path)
-
-    patcher = mock.patch.object(
-        dataset_info.DatasetInfo,
-        "initialize_from_bucket",
-        new=load_mnist_dataset_info,
-    )
-    patcher.start()
-    self.patch_gcs = patcher
-    self.addCleanup(patcher.stop)
-
-  def test_stats_restored_from_gcs(self):
-    with testing.tmp_dir(self.get_temp_dir()) as tmp_dir:
-      builder = testing.DummyMnist(data_dir=tmp_dir)
-      self.assertEqual(builder.info.splits["train"].num_examples, 20)
-
-  def test_stats_not_restored_gcs_overwritten(self):
-    with testing.tmp_dir(self.get_temp_dir()) as tmp_dir:
-      # If split are different that the one restored, stats should be recomputed
-      builder = testing.DummyMnist(data_dir=tmp_dir)
-      self.assertEqual(builder.info.splits["train"].num_examples, 20)
-
-  def test_gcs_not_exists(self):
-    # By disabling the patch, and because DummyMnist is not on GCS, we can
-    # simulate a new dataset starting from scratch
-    self.patch_gcs.stop()
-    with testing.tmp_dir(self.get_temp_dir()) as tmp_dir:
-      builder = testing.DummyMnist(data_dir=tmp_dir)
-      # No dataset_info restored, so stats are empty
-      self.assertEqual(builder.info.splits.total_num_examples, 0)
-
-      dl_config = download.DownloadConfig()
-      builder.download_and_prepare(download_config=dl_config)
-
-      # Statistics should have been recomputed
-      self.assertEqual(builder.info.splits["train"].num_examples, 20)
-    self.patch_gcs.start()
-
-
 class DatasetBuilderGenerateModeTest(testing.TestCase):
 
   @classmethod
