@@ -17,7 +17,14 @@
 
 from tensorflow_datasets.core.dataset_builders.conll.conll_dataset_builder import ConllBuilderConfig
 from tensorflow_datasets.core.dataset_builders.conll.conll_dataset_builder import ConllDatasetBuilder
-from tensorflow_datasets.core.dataset_builders.conll.conll_dataset_builder_utils import *
+from tensorflow_datasets.core.dataset_builders.conll.conll_dataset_builder_utils import CHUNK_TAGS
+from tensorflow_datasets.core.dataset_builders.conll.conll_dataset_builder_utils import CONLL_2002_SEPARATOR
+from tensorflow_datasets.core.dataset_builders.conll.conll_dataset_builder_utils import CONLL_2003_CONFIG
+from tensorflow_datasets.core.dataset_builders.conll.conll_dataset_builder_utils import CONLL_2003_ORDERED_FEATURES
+from tensorflow_datasets.core.dataset_builders.conll.conll_dataset_builder_utils import POS_TAGS
 from tensorflow_datasets.core.dataset_builders.conll.conllu_dataset_builder import ConllUBuilderConfig
 from tensorflow_datasets.core.dataset_builders.conll.conllu_dataset_builder import ConllUDatasetBuilder
-from tensorflow_datasets.core.dataset_builders.conll.conllu_dataset_builder_utils import *
+from tensorflow_datasets.core.dataset_builders.conll.conllu_dataset_builder_utils import get_universal_morphology_config
+from tensorflow_datasets.core.dataset_builders.conll.conllu_dataset_builder_utils import UNIVERSAL_DEPENDENCIES_FEATURES
+from tensorflow_datasets.core.dataset_builders.conll.conllu_dataset_builder_utils import UPOS
+from tensorflow_datasets.core.dataset_builders.conll.conllu_dataset_builder_utils import XTREME_POS_FEATURES
