@@ -18,12 +18,14 @@
 from __future__ import annotations
 
 import dataclasses
+import io
 import os
 import tempfile
 from typing import Any, List, Optional, Union
 
 from etils import epath
 import numpy as np
+from tensorflow_datasets.core import lazy_imports_lib
 from tensorflow_datasets.core import utils
 from tensorflow_datasets.core.features import feature as feature_lib
 from tensorflow_datasets.core.proto import feature_pb2
@@ -289,9 +291,52 @@ class Image(feature_lib.FeatureConnector):
     return self._image_encoder.encode_image_or_path(image_or_path_or_fobj)
 
   def decode_example(self, example):
-    """Reconstruct the image from the tf example."""
+    """Reconstruct the image with TensorFlow from the tf example."""
     return self._image_encoder.decode_image(example)
 
+  def decode_example_np(self, example: bytes) -> np.ndarray:
+    """Reconstruct the image with PIL from bytes."""
+    channels = self._shape[-1]
+    if self._dtype == np.uint16:
+      # PIL does not handle multi-channel 16-bit images, so we use OpenCV.
+      return self.decode_example_np_with_opencv(example, channels)
+    else:
+      return self.decode_example_np_with_pil(example, channels)
+
+  def decode_example_np_with_opencv(
+      self, example: bytes, channels: int
+  ) -> np.ndarray:
+    try:
+      cv2 = lazy_imports_lib.lazy_imports.cv2
+    except ImportError as e:
+      raise Exception(
+          'Decoding 16-bit images with NumPy requires OpenCV.'
+      ) from e
+    example = np.frombuffer(example, dtype=np.uint8)
+    example = cv2.imdecode(example, cv2.IMREAD_UNCHANGED)
+    if example.ndim == 2:
+      return _reshape_grayscale_image(example, channels)
+    return example[:, :, _opencv_to_tfds_channels(self._shape)]
+
+  def decode_example_np_with_pil(
+      self, example: bytes, channels: int
+  ) -> np.ndarray:
+    try:
+      PIL_Image = lazy_imports_lib.lazy_imports.PIL_Image  # pylint: disable=invalid-name
+    except ImportError as e:
+      raise Exception('Decoding images with NumPy requires PIL.') from e
+    bytes_io = io.BytesIO(example)
+    with PIL_Image.open(bytes_io) as image:
+      dtype = self.np_dtype if self.np_dtype != np.float32 else np.uint8
+      np_array = np.asarray(image, dtype=dtype)
+      np_array = _reshape_grayscale_image(np_array, channels)
+      if self.np_dtype == np.uint8:
+        return np_array
+      # Bitcast 4 channels uint8 -> 1 channel float32.
+      if self.np_dtype == np.float32:
+        return np_array.view(np.float32)
+      raise ValueError(f'decode_example_np does not handle {self.np_dtype}')
+
   def repr_html(self, ex: np.ndarray) -> str:
     """Images are displayed as thumbnail."""
     # Normalize image and resize
@@ -493,3 +538,36 @@ def _validate_np_array(
         f'Image dtype should be {dtype}. Detected: {np_array.dtype}.'
     )
   utils.assert_shape_match(np_array.shape, shape)
+
+
+@py_utils.memoize()
+def _opencv_to_tfds_channels(shape: utils.Shape) -> Union[int, None, List[int]]:
+  """Restore channel in the expected order: OpenCV uses BGR rather than RGB."""
+  num_channels = shape[-1]
+  if num_channels == 3:
+    return [2, 1, 0]  # BGR -> RGB
+  elif num_channels == 4:
+    return [2, 1, 0, 3]  # BGRa -> RGBa
+  else:
+    raise ValueError(f'Unsupported number of channels: {num_channels}')
+
+
+def _reshape_grayscale_image(
+    image: np.ndarray, num_channels: int
+) -> np.ndarray:
+  """Reshape grayscale images: (h, w) or (h, w, 1) -> (h, w, num_channels).
+
+  This reproduces the transformation TensorFlow applies to grayscale images.
+
+  Args:
+    image: An image as an np.ndarray.
+    num_channels: The number of channels in the image feature.
+
+  Returns:
+    The reshaped image.
+  """
+  if image.ndim == 2:  # (h, w)
+    return np.repeat(image[..., None], num_channels, axis=-1)
+  if image.ndim == 3 and image.shape[2] == 1:  # (h, w, 1)
+    return np.repeat(image, num_channels, axis=-1)
+  return image
