@@ -30,10 +30,12 @@ def _try_import(module_name):
     mod = importlib.import_module(module_name)
     return mod
   except ImportError as e:
-    err_msg = ("Failed importing {name}. This likely means that the dataset "
-               "requires additional dependencies that have to be "
-               "manually installed (usually with `pip install {name}`). See "
-               "setup.py extras_require.").format(name=module_name)
+    err_msg = (
+        "Failed importing {name}. This likely means that the dataset "
+        "requires additional dependencies that have to be "
+        "manually installed (usually with `pip install {name}`). See "
+        "setup.py extras_require."
+    ).format(name=module_name)
     utils.reraise(e, suffix=err_msg)
 
 
@@ -65,11 +67,21 @@ class LazyImporter(object):
   def cv2(cls):
     return _try_import("cv2")
 
+  @utils.classproperty
+  @classmethod
+  def datasets(cls):
+    return _try_import("datasets")
+
   @utils.classproperty
   @classmethod
   def envlogger(cls):
     return _try_import("envlogger.reader")
 
+  @utils.classproperty
+  @classmethod
+  def gcsfs_store(cls):
+    return _try_import("gcsfs").GCSFileSystem(token='anon').get_mapper
+
   @utils.classproperty
   @classmethod
   def gcld3(cls):
@@ -206,6 +218,21 @@ class LazyImporter(object):
     """For testing purposes only."""
     return _try_import("test_foo")
 
+  @utils.classproperty
+  @classmethod
+  def zarr(cls):
+    return _try_import("zarr")
+
+  @utils.classproperty
+  @classmethod
+  def conllu(cls):
+    return _try_import("conllu")
+
+  @utils.classproperty
+  @classmethod
+  def huggingface_hub(cls):
+    return _try_import("huggingface_hub")
+
 
 lazy_imports = LazyImporter  # pylint: disable=invalid-name
 
