@@ -38,9 +38,11 @@ def test_load_hf_dataset():
     assert load.builder('huggingface:x/y') is builder
 
 
-@visibility.set_availables_tmp([
-    visibility.DatasetType.COMMUNITY_PUBLIC,
-])
+@visibility.set_availables_tmp(
+    [
+        visibility.DatasetType.COMMUNITY_PUBLIC,
+    ]
+)
 def test_community_public_load():
   with mock.patch(
       'tensorflow_datasets.core.community.community_register.list_builders',
@@ -62,7 +64,8 @@ def test_community_public_load():
 @pytest.fixture(scope='session')
 def dummy_dc_loader() -> load.DatasetCollectionLoader:
   return load.DatasetCollectionLoader(
-      collection=testing.DummyDatasetCollection())
+      collection=testing.DummyDatasetCollection()
+  )
 
 
 def test_dc_loader_name(dummy_dc_loader: load.DatasetCollectionLoader):  # pylint: disable=redefined-outer-name
@@ -86,7 +89,8 @@ def test_load_dataset_split(dummy_dc_loader: load.DatasetCollectionLoader):  # p
     mock_load.return_value = [examples, examples]
     loaded_dataset = dummy_dc_loader.load_dataset('c', split='train')
     mock_load.assert_called_once_with(
-        name='c/e:3.5.7', with_info=False, split=['train'])
+        name='c/e:3.5.7', with_info=False, split=['train']
+    )
     assert loaded_dataset == expected
 
 
@@ -97,12 +101,14 @@ def test_load_dataset_splits(dummy_dc_loader: load.DatasetCollectionLoader):  #
     mock_load.return_value = [examples, examples]
     loaded_dataset = dummy_dc_loader.load_dataset('c', split=['train', 'test'])
     mock_load.assert_called_once_with(
-        name='c/e:3.5.7', with_info=False, split=['train', 'test'])
+        name='c/e:3.5.7', with_info=False, split=['train', 'test']
+    )
     assert loaded_dataset == expected
 
 
 def test_load_dataset_runtime_error(
-    dummy_dc_loader: load.DatasetCollectionLoader):  # pylint: disable=redefined-outer-name
+    dummy_dc_loader: load.DatasetCollectionLoader,
+):  # pylint: disable=redefined-outer-name
   with pytest.raises(RuntimeError, match='Unsupported return type.+'):
     with mock.patch.object(load, 'load', autospec=True) as mock_load:
       examples = tf.data.Dataset.from_tensor_slices([1, 2, 3])
@@ -112,22 +118,23 @@ def test_load_dataset_runtime_error(
 
 def test_load_dataset_key_error(dummy_dc_loader: load.DatasetCollectionLoader):  # pylint: disable=redefined-outer-name
   with pytest.raises(
-      KeyError, match='Dataset d is not included in this collection.+'):
+      KeyError, match='Dataset d is not included in this collection.+'
+  ):
     dummy_dc_loader.load_dataset('d')
 
 
 def test_load_dataset_with_kwargs(
-    dummy_dc_loader: load.DatasetCollectionLoader):  # pylint: disable=redefined-outer-name
+    dummy_dc_loader: load.DatasetCollectionLoader,
+):  # pylint: disable=redefined-outer-name
   with mock.patch.object(load, 'load', autospec=True) as mock_load:
     examples = tf.data.Dataset.from_tensor_slices([1, 2, 3])
     expected = {'train': examples, 'test': examples}
     mock_load.return_value = expected
     loaded_dataset = dummy_dc_loader.load_dataset(
-        'c', loader_kwargs={
-            'with_info': True,
-            'batch_size': 3
-        })
+        'c', loader_kwargs={'with_info': True, 'batch_size': 3}
+    )
 
     mock_load.assert_called_once_with(
-        name='c/e:3.5.7', with_info=False, batch_size=3)
+        name='c/e:3.5.7', with_info=False, batch_size=3
+    )
     assert loaded_dataset == expected
