@@ -48,6 +48,7 @@ from google.protobuf import json_format
 
 class DummyNoConfMnist(testing.DummyDataset):
   """Same as DummyMnist (but declared here to avoid skip_registering issues)."""
+
   VERSION = utils.Version('0.1.0')
 
 
@@ -102,7 +103,8 @@ def test_builder_files_exists(code_builder: dataset_builder.DatasetBuilder):
 
   # If the version is specified but files not found, load from the code
   builder = load.builder(
-      f'{code_builder.name}:*.*.*', data_dir='/tmp/path/tfds/not-exists')
+      f'{code_builder.name}:*.*.*', data_dir='/tmp/path/tfds/not-exists'
+  )
   assert isinstance(builder, type(code_builder))
   assert not isinstance(builder, read_only_builder.ReadOnlyBuilder)
 
@@ -113,12 +115,14 @@ def test_builder_config(code_builder: dataset_builder.DatasetBuilder):
     return
 
   # Remove the registered configs
-  with mock.patch.object(type(code_builder), 'BUILDER_CONFIGS', []), \
-       mock.patch.object(type(code_builder), 'builder_configs', {}):
+  with mock.patch.object(
+      type(code_builder), 'BUILDER_CONFIGS', []
+  ), mock.patch.object(type(code_builder), 'builder_configs', {}):
     # Config isn't present in the code anymore
     with pytest.raises(ValueError, match='BuilderConfig .* not found'):
       load.builder(
-          f'{code_builder.name}/dummy_config', data_dir='/tmp/path/not-exists')
+          f'{code_builder.name}/dummy_config', data_dir='/tmp/path/not-exists'
+      )
 
     # But previously generated configs still be loaded from disk
     builder = load.builder(f'{code_builder.name}/dummy_config')
@@ -142,8 +146,10 @@ def test_builder_code_not_found(code_builder: dataset_builder.DatasetBuilder):
 
     if code_builder.builder_config:
       # When the code isn't found, default config is inferred from `.config/`
-      assert (builder.builder_config.name ==
-              code_builder.default_builder_config.name)
+      assert (
+          builder.builder_config.name
+          == code_builder.default_builder_config.name
+      )
 
       # Explicitly passing a config should works too.
       config_name = f'{code_builder.name}/{code_builder.builder_config.name}'
@@ -156,7 +162,8 @@ def test_builder_code_not_found(code_builder: dataset_builder.DatasetBuilder):
 
     with pytest.raises(registered.DatasetNotFoundError):
       load.load(
-          code_builder.name, split=[], data_dir='/tmp/non-existing/tfds/dir')
+          code_builder.name, split=[], data_dir='/tmp/non-existing/tfds/dir'
+      )
 
 
 # Test both with and without config
@@ -210,9 +217,11 @@ def test_builder_from_metadata(code_builder: dataset_builder.DatasetBuilder):
       version='0.1.0',
       release_notes={'0.1.0': 'release description'},
       citation='some citation',
-      features=features.to_proto())
+      features=features.to_proto(),
+  )
   builder = read_only_builder.builder_from_metadata(
-      code_builder.data_dir, info_proto=info_proto)
+      code_builder.data_dir, info_proto=info_proto
+  )
   assert builder.name == info_proto.name
   assert builder.info.description == info_proto.description
   assert builder.info.citation == info_proto.citation
@@ -240,7 +249,9 @@ def test_builder_from_files_multi_dir(
   builder = read_only_builder.builder_from_files(
       code_builder.name,
       data_dir=[
-          code_builder._data_dir_root, some_dir, '/tmp/non-existing-dir/'
+          code_builder._data_dir_root,
+          some_dir,
+          '/tmp/non-existing-dir/',
       ],
   )
   assert builder.name == code_builder.name
@@ -254,7 +265,8 @@ def test_not_registered():
 
 # We assume that all datasets are added into `data_dir='path/to'`
 _find_builder_dir = functools.partial(
-    read_only_builder._find_builder_dir, data_dir='path/to')
+    read_only_builder._find_builder_dir, data_dir='path/to'
+)
 
 
 @contextlib.contextmanager
@@ -268,12 +280,15 @@ def _assert_raises(msg):
 def test_find_builder_dir_with_namespace_given():
   namespace = 'ns'
   ds = f'{namespace}:ds'
-  error_msg = re.escape('\t'.join([
-      '\nBuilder cannot be loaded from files if it uses:',
-      f'* namespaces (here, {namespace} is used)'
-  ]))
-  with pytest.raises(registered.DatasetNotFoundError, match=error_msg), \
-      error_utils.reraise_with_context(registered.DatasetNotFoundError):
+  error_msg = re.escape(
+      '\t'.join([
+          '\nBuilder cannot be loaded from files if it uses:',
+          f'* namespaces (here, {namespace} is used)',
+      ])
+  )
+  with pytest.raises(
+      registered.DatasetNotFoundError, match=error_msg
+  ), error_utils.reraise_with_context(registered.DatasetNotFoundError):
     _find_builder_dir(ds)
     raise registered.DatasetNotFoundError
 
@@ -365,11 +380,11 @@ def test_find_builder_config_code(mock_fs: testing.MockFs):
 
   class MyDataset(testing.DummyMnist):  # pylint: disable=unused-variable
     """Dummy dataset."""
+
     BUILDER_CONFIGS = [
         dataset_builder.BuilderConfig(  # pylint: disable=g-complex-comprehension
-            name=name,
-            version='2.0.0',
-            description=f'{name} description')
+            name=name, version='2.0.0', description=f'{name} description'
+        )
         for name in ('default_config', 'other_config')
     ]
 
@@ -386,22 +401,32 @@ def test_find_builder_config_code(mock_fs: testing.MockFs):
   # If code can be reached, use it to load the default config name.
   # Note that the existing version is loaded, even if the code is at a
   # more recent version.
-  assert (_find_builder_dir('my_dataset') ==
-          'path/to/my_dataset/default_config/1.0.0')
+  assert (
+      _find_builder_dir('my_dataset')
+      == 'path/to/my_dataset/default_config/1.0.0'
+  )
   # Old version from previous configs.
   assert _find_builder_dir('my_dataset:0.0.1') == 'path/to/my_dataset/0.0.1'
   # Explicitly given version with no config, use folder without config.
   assert _find_builder_dir('my_dataset:0.1.0') == 'path/to/my_dataset/0.1.0'
   # Explicitly given version and config, use folder with config.
-  assert (_find_builder_dir('my_dataset/default_config:0.1.0') ==
-          'path/to/my_dataset/default_config/0.1.0')
+  assert (
+      _find_builder_dir('my_dataset/default_config:0.1.0')
+      == 'path/to/my_dataset/default_config/0.1.0'
+  )
   # When config is explicitly given, load the last detected version.
-  assert (_find_builder_dir('my_dataset/other_config') ==
-          'path/to/my_dataset/other_config/1.0.0')
-  assert (_find_builder_dir('my_dataset/old_config') ==
-          'path/to/my_dataset/old_config/1.0.0')
-  assert (_find_builder_dir('my_dataset/old_config:0.8.0') ==
-          'path/to/my_dataset/old_config/0.8.0')
+  assert (
+      _find_builder_dir('my_dataset/other_config')
+      == 'path/to/my_dataset/other_config/1.0.0'
+  )
+  assert (
+      _find_builder_dir('my_dataset/old_config')
+      == 'path/to/my_dataset/old_config/1.0.0'
+  )
+  assert (
+      _find_builder_dir('my_dataset/old_config:0.8.0')
+      == 'path/to/my_dataset/old_config/0.8.0'
+  )
   # When no config found, return None.
   assert _find_builder_dir('my_dataset/broken_config') is None
   assert _find_builder_dir('my_dataset/unknown_config') is None
@@ -413,22 +438,22 @@ def test_get_default_config_name_permission_error():
   error_msg = f'Permission error when accessing: {builder_dir}'
   with _assert_raises(error_msg):
     with mock.patch.object(
-        registered, 'imported_builder_cls', side_effect=PermissionError):
+        registered, 'imported_builder_cls', side_effect=PermissionError
+    ):
       actual_default_config_name = read_only_builder._get_default_config_name(
-          builder_dir=builder_dir, name='name')
+          builder_dir=builder_dir, name='name'
+      )
       assert actual_default_config_name is None
 
 
 def test_get_version_str(mock_fs: testing.MockFs):
-
   mock_fs.add_file('path/to/ds/1.0.0/features.json')
   mock_fs.add_file('path/to/ds/1.0.1/features.json')
   mock_fs.add_file('path/to/ds/1.1.0/features.json')
   mock_fs.add_file('path/to/ds/2.0.1/features.json')
 
   get_version_str = functools.partial(
-      read_only_builder._get_version_str,
-      'path/to/ds/'  # pylint: disable=protected-access
+      read_only_builder._get_version_str, 'path/to/ds/'  # pylint: disable=protected-access
   )
 
   with error_utils.reraise_with_context(registered.DatasetNotFoundError):
@@ -452,8 +477,10 @@ def test_get_version_str(mock_fs: testing.MockFs):
   # No matching version found, updated error context.
   requested_version = '1.3.*'
   builder_dir = 'path/to/ds/'
-  error_msg = (f'No version matching the requested {requested_version} was '
-               f'found in the builder directory: {builder_dir}.')
+  error_msg = (
+      f'No version matching the requested {requested_version} was '
+      f'found in the builder directory: {builder_dir}.'
+  )
 
   with _assert_raises(error_msg):
     assert get_version_str(requested_version=requested_version) is None
@@ -461,13 +488,13 @@ def test_get_version_str(mock_fs: testing.MockFs):
 
 def test_get_version_str_empty_builder_dir(mock_fs: testing.MockFs):
   builder_dir = 'path/to/ds/'
-  error_msg = (f'The builder directory {builder_dir} doesn\'t contain any '
-               'versions.')
+  error_msg = (
+      f"The builder directory {builder_dir} doesn't contain any versions."
+  )
 
   mock_fs.add_file(f'{builder_dir}features.json')
   get_version_str = functools.partial(
-      read_only_builder._get_version_str,
-      'path/to/ds/'  # pylint: disable=protected-access
+      read_only_builder._get_version_str, 'path/to/ds/'  # pylint: disable=protected-access
   )
 
   with _assert_raises(error_msg):
@@ -475,24 +502,29 @@ def test_get_version_str_empty_builder_dir(mock_fs: testing.MockFs):
 
 
 def test_builder_from_directories_splits(mock_fs: testing.MockFs):
-
   def split_for(name: str, shard_lengths: Sequence[int]) -> proto.SplitInfo:
     return proto.SplitInfo(name=name, shard_lengths=shard_lengths)
 
   def dataset_info(splits):
     text_feature = proto.feature_pb2.Feature(
         python_class_name='tensorflow_datasets.core.features.text_feature.Text',
-        text=proto.feature_pb2.TextFeature())
+        text=proto.feature_pb2.TextFeature(),
+    )
     features = proto.feature_pb2.Feature(
-        python_class_name='tensorflow_datasets.core.features.features_dict.FeaturesDict',
+        python_class_name=(
+            'tensorflow_datasets.core.features.features_dict.FeaturesDict'
+        ),
         features_dict=proto.feature_pb2.FeaturesDict(
-            features={'text': text_feature}))
+            features={'text': text_feature}
+        ),
+    )
     return proto.dataset_info_pb2.DatasetInfo(
         name='ds_name',
         version='1.0.0',
         file_format='tfrecord',
         splits=splits,
-        features=features)
+        features=features,
+    )
 
   split_train_1 = split_for('train', [4, 5])
   split_test_1 = split_for('test', [3])
@@ -512,17 +544,22 @@ def test_builder_from_directories_splits(mock_fs: testing.MockFs):
   assert isinstance(result.info.splits['train'], splits_lib.MultiSplitInfo)
   assert isinstance(result.info.splits['test'], splits_lib.MultiSplitInfo)
 
-  assert str(result.info.splits['test']) == (
-      'MultiSplitInfo(name=\'test\', '
-      'split_infos=[<SplitInfo num_examples=3, num_shards=1>])')
-  assert str(result.info.splits['train']) == (
-      'MultiSplitInfo(name=\'train\', split_infos=['
+  assert (
+      str(result.info.splits['test'])
+      == "MultiSplitInfo(name='test', "
+      'split_infos=[<SplitInfo num_examples=3, num_shards=1>])'
+  )
+  assert (
+      str(result.info.splits['train'])
+      == "MultiSplitInfo(name='train', split_infos=["
       '<SplitInfo num_examples=9, num_shards=2>, '
-      '<SplitInfo num_examples=10, num_shards=2>])')
+      '<SplitInfo num_examples=10, num_shards=2>])'
+  )
 
 
 def test_builder_from_directories_reading(
-    code_builder: dataset_builder.DatasetBuilder):
+    code_builder: dataset_builder.DatasetBuilder,
+):
   other_dir1 = f'{code_builder.data_dir}/other1'
   other_dir2 = f'{code_builder.data_dir}/other2'
 
@@ -533,12 +570,15 @@ def test_builder_from_directories_reading(
     filepath = f'{code_builder.data_dir}/{filename}'
     if not tf.io.gfile.isdir(filepath):
       tf.io.gfile.copy(
-          src=filepath, dst=f'{other_dir1}/{filename}', overwrite=True)
+          src=filepath, dst=f'{other_dir1}/{filename}', overwrite=True
+      )
       tf.io.gfile.copy(
-          src=filepath, dst=f'{other_dir2}/{filename}', overwrite=True)
+          src=filepath, dst=f'{other_dir2}/{filename}', overwrite=True
+      )
 
   builder = read_only_builder.builder_from_directories(
-      [other_dir1, other_dir2, code_builder.data_dir])
+      [other_dir1, other_dir2, code_builder.data_dir]
+  )
   train_np = dataset_utils.as_numpy(builder.as_dataset(split='train'))
   assert len(train_np) == 9
   ds = dataset_utils.as_numpy(builder.as_dataset(split='train').take(5))
