@@ -22,14 +22,16 @@ import random
 
 from absl import app
 from absl import flags
-from tensorflow_datasets.core.utils import py_utils
+from tensorflow_datasets.core import utils
 from tensorflow_datasets.core.utils.lazy_imports_utils import tensorflow as tf
 from tensorflow_datasets.datasets.bccd import bccd_dataset_builder
 import tensorflow_datasets.public_api as tfds
 from tensorflow_datasets.testing import fake_data_utils
 
 flags.DEFINE_string(
-    "tfds_dir", py_utils.tfds_dir(), "Path to tensorflow_datasets directory"
+    "tfds_dir",
+    os.fspath(utils.tfds_write_path()),
+    "Path to tensorflow_datasets directory",
 )
 FLAGS = flags.FLAGS
 
