@@ -74,11 +74,14 @@ def disk(radius, alias_blur=0.1, dtype=np.float32):
     length = np.arange(-radius, radius + 1)
     ksize = (5, 5)
   x_axis, y_axis = np.meshgrid(length, length)
-  aliased_disk = np.array((x_axis**2 + y_axis**2) <= radius**2, dtype=dtype)
+  aliased_disk = np.array(
+      (x_axis**2 + y_axis**2) <= radius**2, dtype=dtype
+  )
   aliased_disk /= np.sum(aliased_disk)
   # supersample disk to antialias
   return tfds.core.lazy_imports.cv2.GaussianBlur(
-      aliased_disk, ksize=ksize, sigmaX=alias_blur)
+      aliased_disk, ksize=ksize, sigmaX=alias_blur
+  )
 
 
 def clipped_zoom(img, zoom_factor):
@@ -102,14 +105,16 @@ def clipped_zoom(img, zoom_factor):
   top_w = (w - cw) // 2
 
   img = tfds.core.lazy_imports.scipy.ndimage.zoom(
-      img[top_h:top_h + ch, top_w:top_w + cw], (zoom_factor, zoom_factor, 1),
-      order=1)
+      img[top_h : top_h + ch, top_w : top_w + cw],
+      (zoom_factor, zoom_factor, 1),
+      order=1,
+  )
 
   # trim off any extra pixels
   trim_top_h = (img.shape[0] - h) // 2
   trim_top_w = (img.shape[1] - w) // 2
 
-  return img[trim_top_h:trim_top_h + h, trim_top_w:trim_top_w + w]
+  return img[trim_top_h : trim_top_h + h, trim_top_w : trim_top_w + w]
 
 
 def plasma_fractal(mapsize=512, wibbledecay=3):
@@ -140,25 +145,29 @@ def plasma_fractal(mapsize=512, wibbledecay=3):
     cornerref = maparray[0:mapsize:stepsize, 0:mapsize:stepsize]
     squareaccum = cornerref + np.roll(cornerref, shift=-1, axis=0)
     squareaccum += np.roll(squareaccum, shift=-1, axis=1)
-    maparray[stepsize // 2:mapsize:stepsize,
-             stepsize // 2:mapsize:stepsize] = wibbledmean(squareaccum)
+    maparray[
+        stepsize // 2 : mapsize : stepsize, stepsize // 2 : mapsize : stepsize
+    ] = wibbledmean(squareaccum)
 
   def filldiamonds():
     """For each diamond, calculate middle value as meanof points + wibble."""
     mapsize = maparray.shape[0]
-    drgrid = maparray[stepsize // 2:mapsize:stepsize,
-                      stepsize // 2:mapsize:stepsize]
+    drgrid = maparray[
+        stepsize // 2 : mapsize : stepsize, stepsize // 2 : mapsize : stepsize
+    ]
     ulgrid = maparray[0:mapsize:stepsize, 0:mapsize:stepsize]
     ldrsum = drgrid + np.roll(drgrid, 1, axis=0)
     lulsum = ulgrid + np.roll(ulgrid, -1, axis=1)
     ltsum = ldrsum + lulsum
-    maparray[0:mapsize:stepsize,
-             stepsize // 2:mapsize:stepsize] = wibbledmean(ltsum)
+    maparray[0:mapsize:stepsize, stepsize // 2 : mapsize : stepsize] = (
+        wibbledmean(ltsum)
+    )
     tdrsum = drgrid + np.roll(drgrid, 1, axis=1)
     tulsum = ulgrid + np.roll(ulgrid, -1, axis=0)
     ttsum = tdrsum + tulsum
-    maparray[stepsize // 2:mapsize:stepsize,
-             0:mapsize:stepsize] = wibbledmean(ttsum)
+    maparray[stepsize // 2 : mapsize : stepsize, 0:mapsize:stepsize] = (
+        wibbledmean(ttsum)
+    )
 
   while stepsize >= 2:
     fillsquares()
@@ -185,8 +194,8 @@ def gaussian_noise(x, severity=1):
   Returns:
     numpy array, image with uint8 pixels in [0,255]. Added Gaussian noise.
   """
-  c = [.08, .12, 0.18, 0.26, 0.38][severity - 1]
-  x = np.array(x) / 255.
+  c = [0.08, 0.12, 0.18, 0.26, 0.38][severity - 1]
+  x = np.array(x) / 255.0
   x_clip = np.clip(x + np.random.normal(size=x.shape, scale=c), 0, 1) * 255
   return around_and_astype(x_clip)
 
@@ -202,7 +211,7 @@ def shot_noise(x, severity=1):
     numpy array, image with uint8 pixels in [0,255]. Added shot noise.
   """
   c = [60, 25, 12, 5, 3][severity - 1]
-  x = np.array(x) / 255.
+  x = np.array(x) / 255.0
   x_clip = np.clip(np.random.poisson(x * c) / float(c), 0, 1) * 255
   return around_and_astype(x_clip)
 
@@ -217,9 +226,10 @@ def impulse_noise(x, severity=1):
   Returns:
     numpy array, image with uint8 pixels in [0,255]. Added impulse noise.
   """
-  c = [.03, .06, .09, 0.17, 0.27][severity - 1]
+  c = [0.03, 0.06, 0.09, 0.17, 0.27][severity - 1]
   x = tfds.core.lazy_imports.skimage.util.random_noise(
-      np.array(x) / 255., mode='s&p', amount=c)
+      np.array(x) / 255.0, mode='s&p', amount=c
+  )
   x_clip = np.clip(x, 0, 1) * 255
   return around_and_astype(x_clip)
 
@@ -237,7 +247,7 @@ def defocus_blur(x, severity=1):
     numpy array, image with uint8 pixels in [0,255]. Applied defocus blur.
   """
   c = [(3, 0.1), (4, 0.5), (6, 0.5), (8, 0.5), (10, 0.5)][severity - 1]
-  x = np.array(x) / 255.
+  x = np.array(x) / 255.0
   kernel = disk(radius=c[0], alias_blur=c[1])
   channels = []
   for d in range(3):
@@ -260,11 +270,15 @@ def glass_blur(x, severity=1):
     numpy array, image with uint8 pixels in [0,255]. Applied frosted glass blur.
   """
   # sigma, max_delta, iterations
-  c = [(0.7, 1, 2), (0.9, 2, 1), (1, 2, 3), (1.1, 3, 2),
-       (1.5, 4, 2)][severity - 1]
+  c = [(0.7, 1, 2), (0.9, 2, 1), (1, 2, 3), (1.1, 3, 2), (1.5, 4, 2)][
+      severity - 1
+  ]
   x = np.uint8(
       tfds.core.lazy_imports.skimage.filters.gaussian(
-          np.array(x) / 255., sigma=c[0], multichannel=True) * 255)
+          np.array(x) / 255.0, sigma=c[0], multichannel=True
+      )
+      * 255
+  )
 
   # locally shuffle pixels
   for _ in range(c[2]):
@@ -276,7 +290,11 @@ def glass_blur(x, severity=1):
         x[h, w], x[h_prime, w_prime] = x[h_prime, w_prime], x[h, w]
   x_clip = np.clip(
       tfds.core.lazy_imports.skimage.filters.gaussian(
-          x / 255., sigma=c[0], multichannel=True), 0, 1)
+          x / 255.0, sigma=c[0], multichannel=True
+      ),
+      0,
+      1,
+  )
   x_clip *= 255
   return around_and_astype(x_clip)
 
@@ -298,9 +316,9 @@ def zoom_blur(x, severity=1):
       np.arange(1, 1.16, 0.01),
       np.arange(1, 1.21, 0.02),
       np.arange(1, 1.26, 0.02),
-      np.arange(1, 1.31, 0.03)
+      np.arange(1, 1.31, 0.03),
   ][severity - 1]
-  x = (np.array(x) / 255.).astype(np.float32)
+  x = (np.array(x) / 255.0).astype(np.float32)
   out = np.zeros_like(x)
   for zoom_factor in c:
     out += clipped_zoom(x, zoom_factor)
@@ -321,16 +339,16 @@ def fog(x, severity=1):
   Returns:
     numpy array, image with uint8 pixels in [0,255]. Added fog.
   """
-  c = [(1.5, 2), (2., 2), (2.5, 1.7), (2.5, 1.5), (3., 1.4)][severity - 1]
-  x = np.array(x) / 255.
+  c = [(1.5, 2), (2.0, 2), (2.5, 1.7), (2.5, 1.5), (3.0, 1.4)][severity - 1]
+  x = np.array(x) / 255.0
   max_val = x.max()
   mapsize = 512
   shape = x.shape
   max_length = max(shape[0], shape[1])
   if max_length > mapsize:
-    mapsize = 2**int(np.ceil(np.log2(float(max_length))))
+    mapsize = 2 ** int(np.ceil(np.log2(float(max_length))))
   tmp = plasma_fractal(mapsize=mapsize, wibbledecay=c[1])
-  tmp = tmp[:x.shape[0], :x.shape[1]]
+  tmp = tmp[: x.shape[0], : x.shape[1]]
   tmp = tmp[..., np.newaxis]
   x += c[0] * tmp
   x_clip = np.clip(x * max_val / (max_val + c[0]), 0, 1) * 255
@@ -347,9 +365,9 @@ def brightness(x, severity=1):
   Returns:
     numpy array, image with uint8 pixels in [0,255]. Changed brightness.
   """
-  c = [.1, .2, .3, .4, .5][severity - 1]
+  c = [0.1, 0.2, 0.3, 0.4, 0.5][severity - 1]
 
-  x = np.array(x) / 255.
+  x = np.array(x) / 255.0
   x = tfds.core.lazy_imports.skimage.color.rgb2hsv(x)
   x[:, :, 2] = np.clip(x[:, :, 2] + c, 0, 1)
   x = tfds.core.lazy_imports.skimage.color.hsv2rgb(x)
@@ -367,9 +385,9 @@ def contrast(x, severity=1):
   Returns:
     numpy array, image with uint8 pixels in [0,255]. Changed contrast.
   """
-  c = [0.4, .3, .2, .1, .05][severity - 1]
+  c = [0.4, 0.3, 0.2, 0.1, 0.05][severity - 1]
 
-  x = np.array(x) / 255.
+  x = np.array(x) / 255.0
   means = np.mean(x, axis=(0, 1), keepdims=True)
   x_clip = np.clip((x - means) * c + means, 0, 1) * 255
   return around_and_astype(x_clip)
@@ -387,12 +405,15 @@ def elastic_transform(x, severity=1):
   Returns:
     numpy array, image with uint8 pixels in [0,255]. Applied elastic transform.
   """
-  c = [(244 * 2, 244 * 0.7, 244 * 0.1), (244 * 2, 244 * 0.08, 244 * 0.2),
-       (244 * 0.05, 244 * 0.01, 244 * 0.02),
-       (244 * 0.07, 244 * 0.01, 244 * 0.02),
-       (244 * 0.12, 244 * 0.01, 244 * 0.02)][severity - 1]
+  c = [
+      (244 * 2, 244 * 0.7, 244 * 0.1),
+      (244 * 2, 244 * 0.08, 244 * 0.2),
+      (244 * 0.05, 244 * 0.01, 244 * 0.02),
+      (244 * 0.07, 244 * 0.01, 244 * 0.02),
+      (244 * 0.12, 244 * 0.01, 244 * 0.02),
+  ][severity - 1]
 
-  image = np.array(x, dtype=np.float32) / 255.
+  image = np.array(x, dtype=np.float32) / 255.0
   shape = image.shape
   shape_size = shape[:2]
 
@@ -402,37 +423,57 @@ def elastic_transform(x, severity=1):
   pts1 = np.float32([
       center_square + square_size,
       [center_square[0] + square_size, center_square[1] - square_size],
-      center_square - square_size
+      center_square - square_size,
   ])
-  pts2 = pts1 + np.random.uniform(
-      -c[2], c[2], size=pts1.shape).astype(np.float32)
+  pts2 = pts1 + np.random.uniform(-c[2], c[2], size=pts1.shape).astype(
+      np.float32
+  )
   affine_trans = tfds.core.lazy_imports.cv2.getAffineTransform(pts1, pts2)
   image = tfds.core.lazy_imports.cv2.warpAffine(
       image,
       affine_trans,
       shape_size[::-1],
-      borderMode=tfds.core.lazy_imports.cv2.BORDER_REFLECT_101)
+      borderMode=tfds.core.lazy_imports.cv2.BORDER_REFLECT_101,
+  )
 
-  dx = (tfds.core.lazy_imports.skimage.filters.gaussian(
-      np.random.uniform(-1, 1, size=shape[:2]),
-      c[1],
-      mode='reflect',
-      truncate=3) * c[0]).astype(np.float32)
-  dy = (tfds.core.lazy_imports.skimage.filters.gaussian(
-      np.random.uniform(-1, 1, size=shape[:2]),
-      c[1],
-      mode='reflect',
-      truncate=3) * c[0]).astype(np.float32)
+  dx = (
+      tfds.core.lazy_imports.skimage.filters.gaussian(
+          np.random.uniform(-1, 1, size=shape[:2]),
+          c[1],
+          mode='reflect',
+          truncate=3,
+      )
+      * c[0]
+  ).astype(np.float32)
+  dy = (
+      tfds.core.lazy_imports.skimage.filters.gaussian(
+          np.random.uniform(-1, 1, size=shape[:2]),
+          c[1],
+          mode='reflect',
+          truncate=3,
+      )
+      * c[0]
+  ).astype(np.float32)
   dx, dy = dx[..., np.newaxis], dy[..., np.newaxis]
 
   x, y, z = np.meshgrid(
-      np.arange(shape[1]), np.arange(shape[0]), np.arange(shape[2]))
-  indices = np.reshape(y + dy,
-                       (-1, 1)), np.reshape(x + dx,
-                                            (-1, 1)), np.reshape(z, (-1, 1))
-  x_clip = np.clip(
-      tfds.core.lazy_imports.scipy.ndimage.interpolation.map_coordinates(
-          image, indices, order=1, mode='reflect').reshape(shape), 0, 1) * 255
+      np.arange(shape[1]), np.arange(shape[0]), np.arange(shape[2])
+  )
+  indices = (
+      np.reshape(y + dy, (-1, 1)),
+      np.reshape(x + dx, (-1, 1)),
+      np.reshape(z, (-1, 1)),
+  )
+  x_clip = (
+      np.clip(
+          tfds.core.lazy_imports.scipy.ndimage.interpolation.map_coordinates(
+              image, indices, order=1, mode='reflect'
+          ).reshape(shape),
+          0,
+          1,
+      )
+      * 255
+  )
   return around_and_astype(x_clip)
 
 
@@ -494,10 +535,11 @@ def frost(x, severity=1):
     frost_img = tfds.core.lazy_imports.cv2.imread(im_frost.name)
   # randomly crop and convert to rgb
   x_start, y_start = np.random.randint(
-      0, frost_img.shape[0] - 224), np.random.randint(0,
-                                                      frost_img.shape[1] - 224)
-  frost_img = frost_img[x_start:x_start + 224, y_start:y_start + 224][...,
-                                                                      [2, 1, 0]]
+      0, frost_img.shape[0] - 224
+  ), np.random.randint(0, frost_img.shape[1] - 224)
+  frost_img = frost_img[x_start : x_start + 224, y_start : y_start + 224][
+      ..., [2, 1, 0]
+  ]
 
   x = np.clip(c[0] * np.array(x) + c[1] * frost_img, 0, 255)
 
@@ -516,19 +558,25 @@ def snow(x, severity=1):
   """
   cv2 = tfds.core.lazy_imports.cv2
   PIL_Image = tfds.core.lazy_imports.PIL_Image  # pylint: disable=invalid-name
-  c = [(0.1, 0.3, 3, 0.5, 10, 4, 0.8), (0.2, 0.3, 2, 0.5, 12, 4, 0.7),
-       (0.55, 0.3, 4, 0.9, 12, 8, 0.7), (0.55, 0.3, 4.5, 0.85, 12, 8, 0.65),
-       (0.55, 0.3, 2.5, 0.85, 12, 12, 0.55)][severity - 1]
+  c = [
+      (0.1, 0.3, 3, 0.5, 10, 4, 0.8),
+      (0.2, 0.3, 2, 0.5, 12, 4, 0.7),
+      (0.55, 0.3, 4, 0.9, 12, 8, 0.7),
+      (0.55, 0.3, 4.5, 0.85, 12, 8, 0.65),
+      (0.55, 0.3, 2.5, 0.85, 12, 12, 0.55),
+  ][severity - 1]
 
-  x = np.array(x, dtype=np.float32) / 255.
+  x = np.array(x, dtype=np.float32) / 255.0
   snow_layer = np.random.normal(
-      size=x.shape[:2], loc=c[0], scale=c[1])  # [:2] for monochrome
+      size=x.shape[:2], loc=c[0], scale=c[1]
+  )  # [:2] for monochrome
 
   snow_layer = clipped_zoom(snow_layer[..., np.newaxis], c[2])
   snow_layer[snow_layer < c[3]] = 0
 
   snow_layer = PIL_Image.fromarray(
-      (np.clip(snow_layer.squeeze(), 0, 1) * 255).astype(np.uint8), mode='L')
+      (np.clip(snow_layer.squeeze(), 0, 1) * 255).astype(np.uint8), mode='L'
+  )
 
   with tempfile.NamedTemporaryFile() as im_input:
     with tempfile.NamedTemporaryFile() as im_output:
@@ -540,20 +588,25 @@ def snow(x, severity=1):
       angle = np.random.uniform(-135, -45)
 
       subprocess.check_output([
-          convert_bin, '-motion-blur', '{}x{}+{}'.format(radius, sigma, angle),
-          im_input.name, im_output.name
+          convert_bin,
+          '-motion-blur',
+          '{}x{}+{}'.format(radius, sigma, angle),
+          im_input.name,
+          im_output.name,
       ])
 
       with open(im_output.name, 'rb') as f:
         output = f.read()
 
-  snow_layer = cv2.imdecode(
-      np.frombuffer(output, np.uint8), cv2.IMREAD_UNCHANGED) / 255.
+  snow_layer = (
+      cv2.imdecode(np.frombuffer(output, np.uint8), cv2.IMREAD_UNCHANGED)
+      / 255.0
+  )
   snow_layer = snow_layer[..., np.newaxis]
 
   x = c[6] * x + (1 - c[6]) * np.maximum(
-      x,
-      cv2.cvtColor(x, cv2.COLOR_RGB2GRAY).reshape(224, 224, 1) * 1.5 + 0.5)
+      x, cv2.cvtColor(x, cv2.COLOR_RGB2GRAY).reshape(224, 224, 1) * 1.5 + 0.5
+  )
   x = np.clip(x + snow_layer + np.rot90(snow_layer, k=2), 0, 1) * 255
 
   return around_and_astype(x)
@@ -583,8 +636,11 @@ def motion_blur(x, severity=1):
       angle = np.random.uniform(-45, -45)
 
       subprocess.check_output([
-          convert_bin, '-motion-blur', '{}x{}+{}'.format(radius, sigma, angle),
-          im_input.name, im_output.name
+          convert_bin,
+          '-motion-blur',
+          '{}x{}+{}'.format(radius, sigma, angle),
+          im_input.name,
+          im_output.name,
       ])
 
       with open(im_output.name, 'rb') as f:
@@ -592,7 +648,8 @@ def motion_blur(x, severity=1):
 
   x = tfds.core.lazy_imports.cv2.imdecode(
       np.frombuffer(output, np.uint8),
-      tfds.core.lazy_imports.cv2.IMREAD_UNCHANGED)
+      tfds.core.lazy_imports.cv2.IMREAD_UNCHANGED,
+  )
 
   if x.shape != (224, 224):
     x = np.clip(x[..., [2, 1, 0]], 0, 255)  # BGR to RGB
@@ -618,7 +675,8 @@ def gaussian_blur(x, severity=1):
   c = [1, 2, 3, 4, 6][severity - 1]
 
   x = tfds.core.lazy_imports.skimage.filters.gaussian(
-      np.array(x) / 255., sigma=c, multichannel=True)
+      np.array(x) / 255.0, sigma=c, multichannel=True
+  )
   x = np.clip(x, 0, 1) * 255
 
   return around_and_astype(x)
@@ -636,7 +694,7 @@ def saturate(x, severity=1):
   """
   c = [(0.3, 0), (0.1, 0), (2, 0), (5, 0.1), (20, 0.2)][severity - 1]
 
-  x = np.array(x) / 255.
+  x = np.array(x) / 255.0
   x = tfds.core.lazy_imports.skimage.color.rgb2hsv(x)
   x[:, :, 1] = np.clip(x[:, :, 1] * c[0] + c[1], 0, 1)
   x = tfds.core.lazy_imports.skimage.color.hsv2rgb(x)
@@ -657,10 +715,14 @@ def spatter(x, severity=1):
   """
   cv2 = tfds.core.lazy_imports.cv2
   skimage = tfds.core.lazy_imports.skimage
-  c = [(0.65, 0.3, 4, 0.69, 0.6, 0), (0.65, 0.3, 3, 0.68, 0.6, 0),
-       (0.65, 0.3, 2, 0.68, 0.5, 0), (0.65, 0.3, 1, 0.65, 1.5, 1),
-       (0.67, 0.4, 1, 0.65, 1.5, 1)][severity - 1]
-  x = np.array(x, dtype=np.float32) / 255.
+  c = [
+      (0.65, 0.3, 4, 0.69, 0.6, 0),
+      (0.65, 0.3, 3, 0.68, 0.6, 0),
+      (0.65, 0.3, 2, 0.68, 0.5, 0),
+      (0.65, 0.3, 1, 0.65, 1.5, 1),
+      (0.67, 0.4, 1, 0.65, 1.5, 1),
+  ][severity - 1]
+  x = np.array(x, dtype=np.float32) / 255.0
 
   liquid_layer = np.random.normal(size=x.shape[:2], loc=c[0], scale=c[1])
 
@@ -685,9 +747,13 @@ def spatter(x, severity=1):
 
     # water is pale turqouise
     color = np.concatenate(
-        (175 / 255. * np.ones_like(m[..., :1]), 238 / 255. *
-         np.ones_like(m[..., :1]), 238 / 255. * np.ones_like(m[..., :1])),
-        axis=2)
+        (
+            175 / 255.0 * np.ones_like(m[..., :1]),
+            238 / 255.0 * np.ones_like(m[..., :1]),
+            238 / 255.0 * np.ones_like(m[..., :1]),
+        ),
+        axis=2,
+    )
 
     color = cv2.cvtColor(color, cv2.COLOR_BGR2BGRA)
     x = cv2.cvtColor(x, cv2.COLOR_BGR2BGRA)
@@ -701,12 +767,16 @@ def spatter(x, severity=1):
 
     # mud brown
     color = np.concatenate(
-        (63 / 255. * np.ones_like(x[..., :1]), 42 / 255. *
-         np.ones_like(x[..., :1]), 20 / 255. * np.ones_like(x[..., :1])),
-        axis=2)
+        (
+            63 / 255.0 * np.ones_like(x[..., :1]),
+            42 / 255.0 * np.ones_like(x[..., :1]),
+            20 / 255.0 * np.ones_like(x[..., :1]),
+        ),
+        axis=2,
+    )
 
     color *= m[..., np.newaxis]
-    x *= (1 - m[..., np.newaxis])
+    x *= 1 - m[..., np.newaxis]
 
     x = np.clip(x + color, 0, 1) * 255
   return around_and_astype(x)
@@ -722,8 +792,8 @@ def speckle_noise(x, severity=1):
   Returns:
     numpy array, image with uint8 pixels in [0,255]. Applied speckle noise.
   """
-  c = [.15, .2, 0.35, 0.45, 0.6][severity - 1]
+  c = [0.15, 0.2, 0.35, 0.45, 0.6][severity - 1]
 
-  x = np.array(x) / 255.
+  x = np.array(x) / 255.0
   x = np.clip(x + x * np.random.normal(size=x.shape, scale=c), 0, 1) * 255
   return around_and_astype(x)
