@@ -39,7 +39,8 @@ _BTGRAHAM_DESCRIPTION_PATTERN = (
     "Images have been preprocessed as the winner of the Kaggle competition did "
     "in 2015: first they are resized so that the radius of an eyeball is "
     "{} pixels, then they are cropped to 90% of the radius, and finally they "
-    "are encoded with 72 JPEG quality.")
+    "are encoded with 72 JPEG quality."
+)
 
 
 class DiabeticRetinopathyDetectionConfig(tfds.core.BuilderConfig):
@@ -58,7 +59,8 @@ class DiabeticRetinopathyDetectionConfig(tfds.core.BuilderConfig):
         release_notes={
             "3.0.0": "New split API (https://tensorflow.org/datasets/splits)",
         },
-        **kwargs)
+        **kwargs,
+    )
     self._target_pixels = target_pixels
 
   @property
@@ -80,26 +82,32 @@ class DiabeticRetinopathyDetection(tfds.core.GeneratorBasedBuilder):
   BUILDER_CONFIGS = [
       DiabeticRetinopathyDetectionConfig(
           name="original",
-          description="Images at their original resolution and quality."),
+          description="Images at their original resolution and quality.",
+      ),
       DiabeticRetinopathyDetectionConfig(
           name="1M",
           description="Images have roughly 1,000,000 pixels, at 72 quality.",
-          target_pixels=1000000),
+          target_pixels=1000000,
+      ),
       DiabeticRetinopathyDetectionConfig(
           name="250K",
           description="Images have roughly 250,000 pixels, at 72 quality.",
-          target_pixels=250000),
+          target_pixels=250000,
+      ),
       DiabeticRetinopathyDetectionConfig(
           name="btgraham-300",
           description=_BTGRAHAM_DESCRIPTION_PATTERN.format(300),
-          target_pixels=300),
+          target_pixels=300,
+      ),
   ]
 
   def _info(self):
     return tfds.core.DatasetInfo(
         builder=self,
-        description="A large set of high-resolution retina images taken under "
-        "a variety of imaging conditions.",
+        description=(
+            "A large set of high-resolution retina images taken under "
+            "a variety of imaging conditions."
+        ),
         features=tfds.features.FeaturesDict({
             "name": tfds.features.Text(),  # patient ID + eye. eg: "4_left".
             "image": tfds.features.Image(),
@@ -117,8 +125,9 @@ class DiabeticRetinopathyDetection(tfds.core.GeneratorBasedBuilder):
     test_labels_path = dl_manager.download(_URL_TEST_LABELS)
     if tf.io.gfile.isdir(test_labels_path):
       # While testing: download() returns the dir containing the tests files.
-      test_labels_path = os.path.join(test_labels_path,
-                                      "retinopathy_solution.csv")
+      test_labels_path = os.path.join(
+          test_labels_path, "retinopathy_solution.csv"
+      )
     return [
         tfds.core.SplitGenerator(
             name="sample",  # 10 images, to do quicktests using dataset.
@@ -171,13 +180,17 @@ class DiabeticRetinopathyDetection(tfds.core.GeneratorBasedBuilder):
     if csv_path:
       with epath.Path(csv_path).open() as csv_f:
         reader = csv.DictReader(csv_f)
-        data = [(row["image"], int(row["level"]))
-                for row in reader
-                if csv_usage is None or row["Usage"] == csv_usage]
+        data = [
+            (row["image"], int(row["level"]))
+            for row in reader
+            if csv_usage is None or row["Usage"] == csv_usage
+        ]
     else:
-      data = [(fname[:-5], -1)
-              for fname in tf.io.gfile.listdir(images_dir_path)
-              if fname.endswith(".jpeg")]
+      data = [
+          (fname[:-5], -1)
+          for fname in tf.io.gfile.listdir(images_dir_path)
+          if fname.endswith(".jpeg")
+      ]
     for name, label in data:
       image_filepath = "%s/%s.jpeg" % (images_dir_path, name)
       record = {
@@ -194,11 +207,13 @@ class DiabeticRetinopathyDetection(tfds.core.GeneratorBasedBuilder):
             image_fobj=image_fobj,
             filepath=filepath,
             target_pixels=self.builder_config.target_pixels,
-            crop_to_radius=True)
+            crop_to_radius=True,
+        )
       else:
         return _resize_image_if_necessary(
             image_fobj=image_fobj,
-            target_pixels=self.builder_config.target_pixels)
+            target_pixels=self.builder_config.target_pixels,
+        )
 
 
 def _resize_image_if_necessary(image_fobj, target_pixels=None):
@@ -217,7 +232,8 @@ def _resize_image_if_necessary(image_fobj, target_pixels=None):
   cv2 = tfds.core.lazy_imports.cv2
   # Decode image using OpenCV2.
   image = cv2.imdecode(
-      np.frombuffer(image_fobj.read(), dtype=np.uint8), flags=3)
+      np.frombuffer(image_fobj.read(), dtype=np.uint8), flags=3
+  )
   # Get image height and width.
   height, width, _ = image.shape
   actual_pixels = height * width
@@ -229,10 +245,9 @@ def _resize_image_if_necessary(image_fobj, target_pixels=None):
   return io.BytesIO(buff.tobytes())
 
 
-def _btgraham_processing(image_fobj,
-                         filepath,
-                         target_pixels,
-                         crop_to_radius=False):
+def _btgraham_processing(
+    image_fobj, filepath, target_pixels, crop_to_radius=False
+):
   """Process an image as the winner of the 2015 Kaggle competition.
 
   Args:
@@ -247,7 +262,8 @@ def _btgraham_processing(image_fobj,
   cv2 = tfds.core.lazy_imports.cv2
   # Decode image using OpenCV2.
   image = cv2.imdecode(
-      np.frombuffer(image_fobj.read(), dtype=np.uint8), flags=3)
+      np.frombuffer(image_fobj.read(), dtype=np.uint8), flags=3
+  )
   # Process the image.
   image = _scale_radius_size(image, filepath, target_radius_size=target_pixels)
   image = _subtract_local_average(image, target_radius_size=target_pixels)
@@ -255,7 +271,8 @@ def _btgraham_processing(image_fobj,
       image,
       target_radius_size=target_pixels,
       radius_mask_ratio=0.9,
-      crop_to_radius=crop_to_radius)
+      crop_to_radius=crop_to_radius,
+  )
   # Encode the image with quality=72 and store it in a BytesIO object.
   _, buff = cv2.imencode(".jpg", image, [int(cv2.IMWRITE_JPEG_QUALITY), 72])
   return io.BytesIO(buff.tobytes())
@@ -270,7 +287,7 @@ def _scale_radius_size(image, filepath, target_radius_size):
     # Some images in the dataset are corrupted, causing the radius heuristic to
     # fail. In these cases, just assume that the radius is the height of the
     # original image.
-    logging.info("Radius of image \"%s\" could not be determined.", filepath)
+    logging.info('Radius of image "%s" could not be determined.', filepath)
     r = image.shape[0] / 2.0
   s = target_radius_size / r
   return cv2.resize(image, dsize=None, fx=s, fy=s)
@@ -283,10 +300,9 @@ def _subtract_local_average(image, target_radius_size):
   return image
 
 
-def _mask_and_crop_to_radius(image,
-                             target_radius_size,
-                             radius_mask_ratio=0.9,
-                             crop_to_radius=False):
+def _mask_and_crop_to_radius(
+    image, target_radius_size, radius_mask_ratio=0.9, crop_to_radius=False
+):
   """Mask and crop image to the given radius ratio."""
   cv2 = tfds.core.lazy_imports.cv2
   mask = np.zeros(image.shape)
