@@ -23,4 +23,5 @@ tfds.builder_cls('imagenet2012_corrupted')
 from tensorflow_datasets.core import lazy_builder_import
 
 Imagenet2012Corrupted = lazy_builder_import.LazyBuilderImport(
-    'imagenet2012_corrupted')
+    'imagenet2012_corrupted'
+)
