@@ -68,7 +68,8 @@ This version contains images, bounding boxes and labels for the {year} version.
 """
 
 Split = collections.namedtuple(
-    'Split', ['name', 'images', 'annotations', 'annotation_type'])
+    'Split', ['name', 'images', 'annotations', 'annotation_type']
+)
 
 
 class AnnotationType(object):
@@ -76,6 +77,7 @@ class AnnotationType(object):
 
   Splits are annotated with different formats.
   """
+
   BBOXES = 'bboxes'
   PANOPTIC = 'panoptic'
   NONE = 'none'
@@ -86,7 +88,8 @@ class CocoConfig(tfds.core.BuilderConfig):
 
   def __init__(self, splits=None, has_panoptic=False, **kwargs):
     super(CocoConfig, self).__init__(
-        version=tfds.core.Version('1.1.0'), **kwargs)
+        version=tfds.core.Version('1.1.0'), **kwargs
+    )
     self.splits = splits
     self.has_panoptic = has_panoptic
 
@@ -172,7 +175,6 @@ class Coco(tfds.core.GeneratorBasedBuilder):
   ]
 
   def _info(self):
-
     features = {
         # Images can have variable shape
         'image': tfds.features.Image(encoding_format='jpeg'),
@@ -182,27 +184,24 @@ class Coco(tfds.core.GeneratorBasedBuilder):
     # Either uses panotptic or original annotations
     if self.builder_config.has_panoptic:
       features.update({
-          'panoptic_image':
-              tfds.features.Image(encoding_format='png'),
-          'panoptic_image/filename':
-              tfds.features.Text(),
-          'panoptic_objects':
-              tfds.features.Sequence({
-                  'id': np.int64,
-                  # Coco has unique id for each annotation. The id can be used
-                  # for mapping panoptic image to semantic segmentation label.
-                  'area': np.int64,
-                  'bbox': tfds.features.BBoxFeature(),
-                  # Coco2017 has 200 categories but only 133 are present in the
-                  # dataset
-                  'label': tfds.features.ClassLabel(num_classes=133),
-                  'is_crowd': np.bool_,
-              }),
+          'panoptic_image': tfds.features.Image(encoding_format='png'),
+          'panoptic_image/filename': tfds.features.Text(),
+          'panoptic_objects': tfds.features.Sequence({
+              'id': np.int64,
+              # Coco has unique id for each annotation. The id can be used
+              # for mapping panoptic image to semantic segmentation label.
+              'area': np.int64,
+              'bbox': tfds.features.BBoxFeature(),
+              # Coco2017 has 200 categories but only 133 are present in the
+              # dataset
+              'label': tfds.features.ClassLabel(num_classes=133),
+              'is_crowd': np.bool_,
+          }),
       })
     else:
-      features.update({
-          'objects':
-              tfds.features.Sequence({
+      features.update(
+          {
+              'objects': tfds.features.Sequence({
                   'id': np.int64,
                   # Coco has unique id for each annotation. The id can be used
                   # for mapping panoptic image to semantic segmentation label.
@@ -212,7 +211,8 @@ class Coco(tfds.core.GeneratorBasedBuilder):
                   'label': tfds.features.ClassLabel(num_classes=80),
                   'is_crowd': np.bool_,
               }),
-      })
+          }
+      )
     # More info could be added, like segmentation (as png mask), captions,
     # person key-points, more metadata (original flickr url,...).
 
@@ -236,13 +236,15 @@ class Coco(tfds.core.GeneratorBasedBuilder):
     for split in self.builder_config.splits:
       urls['{}_images'.format(split.name)] = 'zips/{}.zip'.format(split.images)
       urls['{}_annotations'.format(split.name)] = 'annotations/{}.zip'.format(
-          split.annotations)
+          split.annotations
+      )
 
     # DownloadManager memoize the url, so duplicate urls will only be downloaded
     # once.
     root_url = 'http://images.cocodataset.org/'
     extracted_paths = dl_manager.download_and_extract(
-        {key: root_url + url for key, url in urls.items()})
+        {key: root_url + url for key, url in urls.items()}
+    )
 
     splits = []
     for split in self.builder_config.splits:
@@ -250,11 +252,14 @@ class Coco(tfds.core.GeneratorBasedBuilder):
       annotations_dir = extracted_paths['{}_annotations'.format(split.name)]
       if self.builder_config.has_panoptic:
         panoptic_image_zip_path = os.path.join(
-            annotations_dir, 'annotations',
-            'panoptic_{}.zip'.format(split.images))
+            annotations_dir,
+            'annotations',
+            'panoptic_{}.zip'.format(split.images),
+        )
         panoptic_dir = dl_manager.extract(panoptic_image_zip_path)
-        panoptic_dir = os.path.join(panoptic_dir,
-                                    'panoptic_{}'.format(split.images))
+        panoptic_dir = os.path.join(
+            panoptic_dir, 'panoptic_{}'.format(split.images)
+        )
       else:
         panoptic_dir = None
       splits.append(
@@ -267,11 +272,13 @@ class Coco(tfds.core.GeneratorBasedBuilder):
                   annotation_type=split.annotation_type,
                   panoptic_dir=panoptic_dir,
               ),
-          ))
+          )
+      )
     return splits
 
-  def _generate_examples(self, image_dir, annotation_dir, split_name,
-                         annotation_type, panoptic_dir):
+  def _generate_examples(
+      self, image_dir, annotation_dir, split_name, annotation_type, panoptic_dir
+  ):
     """Generate examples as dicts.
 
     Args:
@@ -367,7 +374,8 @@ class Coco(tfds.core.GeneratorBasedBuilder):
         #     ]
         # }
         panoptic_annotation = coco_annotation.get_annotations(
-            img_id=image_info['id'])
+            img_id=image_info['id']
+        )
         instances = panoptic_annotation['segments_info']
       else:
         instances = []  # No annotations
@@ -390,13 +398,16 @@ class Coco(tfds.core.GeneratorBasedBuilder):
           'image': os.path.join(image_dir, split_name, image_info['file_name']),
           'image/filename': image_info['file_name'],
           'image/id': image_info['id'],
-          objects_key: [{   # pylint: disable=g-complex-comprehension
-              'id': instance['id'],
-              'area': instance['area'],
-              'bbox': build_bbox(*instance['bbox']),
-              'label': categories_id2name[instance['category_id']],
-              'is_crowd': bool(instance['iscrowd']),
-          } for instance in instances]
+          objects_key: [
+              {  # pylint: disable=g-complex-comprehension
+                  'id': instance['id'],
+                  'area': instance['area'],
+                  'bbox': build_bbox(*instance['bbox']),
+                  'label': categories_id2name[instance['category_id']],
+                  'is_crowd': bool(instance['iscrowd']),
+              }
+              for instance in instances
+          ],
       }
       if self.builder_config.has_panoptic:
         panoptic_filename = panoptic_annotation['file_name']
