@@ -25,19 +25,23 @@ _EPISODE_LENGTH = 1801
 class RluDmlabExploreObjectRewardsMany(dmlab_dataset.DMLabDatasetBuilder):
   """DatasetBuilder for rlu_dmlab_explore_object_rewards_many dataset."""
 
-  VERSION = tfds.core.Version('1.1.0')
+  VERSION = tfds.core.Version('1.2.0')
   RELEASE_NOTES = {
       '1.0.0': 'Initial release.',
       '1.1.0': 'Added is_last.',
+      '1.2.0': 'BGR -> RGB fix for pixel observations.',
   }
 
   # pytype: disable=wrong-keyword-args
   BUILDER_CONFIGS = [
       dmlab_dataset.BuilderConfig(
-          name='training_0', task=_TASK, episode_length=_EPISODE_LENGTH),
+          name='training_0', task=_TASK, episode_length=_EPISODE_LENGTH
+      ),
       dmlab_dataset.BuilderConfig(
-          name='training_1', task=_TASK, episode_length=_EPISODE_LENGTH),
+          name='training_1', task=_TASK, episode_length=_EPISODE_LENGTH
+      ),
       dmlab_dataset.BuilderConfig(
-          name='training_2', task=_TASK, episode_length=_EPISODE_LENGTH)
+          name='training_2', task=_TASK, episode_length=_EPISODE_LENGTH
+      ),
   ]
   # pytype: enable=wrong-keyword-args
