@@ -38,7 +38,8 @@ def test_new_without_args(capsys):
 def test_new_invalid_name():
   # Dataset name is required argument
   error_message = (
-      'Invalid dataset name. It should be a valid Python class name.')
+      'Invalid dataset name. It should be a valid Python class name.'
+  )
   invalid_names = ['foo-15', '15foo']
   for invalid_name in invalid_names:
     with pytest.raises(ValueError) as execution_info:
@@ -58,8 +59,8 @@ def test_new_outside_tfds(tmp_path: pathlib.Path):
       '__init__.py',
       'checksums.tsv',
       'dummy_data',
-      'my_dataset.py',
-      'my_dataset_test.py',
+      'my_dataset_dataset_builder.py',
+      'my_dataset_dataset_builder_test.py',
   ]
 
   # If the dataset already exists, raise an error
@@ -80,6 +81,6 @@ def test_new_in_tfds(tmp_path: pathlib.Path):
       '__init__.py',
       'checksums.tsv',
       'dummy_data',
-      'my_dataset.py',
-      'my_dataset_test.py',
+      'my_dataset_dataset_builder.py',
+      'my_dataset_dataset_builder_test.py',
   ]
