@@ -27,10 +27,13 @@ from tensorflow_datasets.core.utils.lazy_imports_utils import tensorflow as tf
 flags.DEFINE_boolean('dry_run', True, 'If True, just print, do nothing.')
 flags.DEFINE_boolean('overwrite', False, 'If True, overwrites the data.')
 flags.DEFINE_string(
-    'from_directory', tfds.core.constants.DATA_DIR,
-    'Where to get the info files from (datasets/ dir on placer).')
-flags.DEFINE_string('to_directory', None,
-                    'Path where dataset info files will be copied.')
+    'from_directory',
+    tfds.core.constants.DATA_DIR,
+    'Where to get the info files from (datasets/ dir on placer).',
+)
+flags.DEFINE_string(
+    'to_directory', None, 'Path where dataset info files will be copied.'
+)
 
 FLAGS = flags.FLAGS
 
