@@ -53,20 +53,21 @@ def _get_table(infobox_line):
   cells = infobox_line.split('\t')
   # remove empty cells
   cells = list(filter(lambda x: x.find('<none>') == -1, cells))
-  columns = set([cell[0:cell.split(':')[0].rfind('_')] for cell in cells])
+  columns = set([cell[0 : cell.split(':')[0].rfind('_')] for cell in cells])
   table = {col: dict() for col in columns}
   for cell in cells:
     delimiter_position_value = cell.find(':')
     column_index = cell[0:delimiter_position_value]
-    value = cell[delimiter_position_value + 1:]
+    value = cell[delimiter_position_value + 1 :]
     delimiter_column_index = column_index.rfind('_')
     column = column_index[0:delimiter_column_index]
-    index = column_index[delimiter_column_index + 1:]
+    index = column_index[delimiter_column_index + 1 :]
     table[column][index] = value
   infobox_line_as_table = []
   for column in table.keys():
     row_value = ' '.join(
-        [table[column][index] for index in sorted(table[column].keys())])
+        [table[column][index] for index in sorted(table[column].keys())]
+    )
     infobox_line_as_table.append({
         'column_header': column,
         'row_number': 1,
@@ -86,15 +87,13 @@ class WikiBio(tfds.core.GeneratorBasedBuilder):
         description=_DESCRIPTION,
         features=tfds.features.FeaturesDict({
             'input_text': {
-                'table':
-                    tfds.features.Sequence({
-                        'column_header': np.str_,
-                        'row_number': np.int16,
-                        'content': np.str_,
-                    }),
+                'table': tfds.features.Sequence({
+                    'column_header': np.str_,
+                    'row_number': np.int16,
+                    'content': np.str_,
+                }),
                 # context will be the article's title
-                'context':
-                    np.str_,
+                'context': np.str_,
             },
             'target_text': np.str_,
         }),
@@ -106,7 +105,8 @@ class WikiBio(tfds.core.GeneratorBasedBuilder):
   def _split_generators(self, dl_manager):
     """Returns SplitGenerators."""
     dataset_url = tfds.download.Resource(
-        url=_URL, extract_method=tfds.download.ExtractMethod.ZIP)
+        url=_URL, extract_method=tfds.download.ExtractMethod.ZIP
+    )
     data_dir = dl_manager.download_and_extract(dataset_url)
 
     extracted_path = os.path.join(data_dir, 'wikipedia-biography-dataset')
@@ -115,68 +115,87 @@ class WikiBio(tfds.core.GeneratorBasedBuilder):
         tfds.core.SplitGenerator(
             name=tfds.Split.TRAIN,
             gen_kwargs={
-                'id_file':
-                    os.path.join(extracted_path, 'train', 'train.id'),
-                'infobox_file':
-                    os.path.join(extracted_path, 'train', 'train.box'),
-                'nb_lines_file':
-                    os.path.join(extracted_path, 'train', 'train.nb'),
-                'sentences_file':
-                    os.path.join(extracted_path, 'train', 'train.sent'),
-                'article_title_file':
-                    os.path.join(extracted_path, 'train', 'train.title'),
+                'id_file': os.path.join(extracted_path, 'train', 'train.id'),
+                'infobox_file': os.path.join(
+                    extracted_path, 'train', 'train.box'
+                ),
+                'nb_lines_file': os.path.join(
+                    extracted_path, 'train', 'train.nb'
+                ),
+                'sentences_file': os.path.join(
+                    extracted_path, 'train', 'train.sent'
+                ),
+                'article_title_file': os.path.join(
+                    extracted_path, 'train', 'train.title'
+                ),
             },
         ),
         tfds.core.SplitGenerator(
             name=tfds.Split.VALIDATION,
             gen_kwargs={
-                'id_file':
-                    os.path.join(extracted_path, 'valid', 'valid.id'),
-                'infobox_file':
-                    os.path.join(extracted_path, 'valid', 'valid.box'),
-                'nb_lines_file':
-                    os.path.join(extracted_path, 'valid', 'valid.nb'),
-                'sentences_file':
-                    os.path.join(extracted_path, 'valid', 'valid.sent'),
-                'article_title_file':
-                    os.path.join(extracted_path, 'valid', 'valid.title'),
+                'id_file': os.path.join(extracted_path, 'valid', 'valid.id'),
+                'infobox_file': os.path.join(
+                    extracted_path, 'valid', 'valid.box'
+                ),
+                'nb_lines_file': os.path.join(
+                    extracted_path, 'valid', 'valid.nb'
+                ),
+                'sentences_file': os.path.join(
+                    extracted_path, 'valid', 'valid.sent'
+                ),
+                'article_title_file': os.path.join(
+                    extracted_path, 'valid', 'valid.title'
+                ),
             },
         ),
         tfds.core.SplitGenerator(
             name=tfds.Split.TEST,
             gen_kwargs={
-                'id_file':
-                    os.path.join(extracted_path, 'test', 'test.id'),
-                'infobox_file':
-                    os.path.join(extracted_path, 'test', 'test.box'),
-                'nb_lines_file':
-                    os.path.join(extracted_path, 'test', 'test.nb'),
-                'sentences_file':
-                    os.path.join(extracted_path, 'test', 'test.sent'),
-                'article_title_file':
-                    os.path.join(extracted_path, 'test', 'test.title'),
+                'id_file': os.path.join(extracted_path, 'test', 'test.id'),
+                'infobox_file': os.path.join(
+                    extracted_path, 'test', 'test.box'
+                ),
+                'nb_lines_file': os.path.join(
+                    extracted_path, 'test', 'test.nb'
+                ),
+                'sentences_file': os.path.join(
+                    extracted_path, 'test', 'test.sent'
+                ),
+                'article_title_file': os.path.join(
+                    extracted_path, 'test', 'test.title'
+                ),
             },
         ),
     ]
 
-  def _generate_examples(self, id_file, infobox_file, nb_lines_file,
-                         sentences_file, article_title_file):
+  def _generate_examples(
+      self,
+      id_file,
+      infobox_file,
+      nb_lines_file,
+      sentences_file,
+      article_title_file,
+  ):
     """Yields examples."""
     with tf.io.gfile.GFile(id_file) as id_src, tf.io.gfile.GFile(
-        infobox_file) as infobox_src, tf.io.gfile.GFile(
-            nb_lines_file) as nb_lines_src, tf.io.gfile.GFile(
-                sentences_file) as sentences_src, tf.io.gfile.GFile(
-                    article_title_file) as article_title_src:
-      for id_, infobox, nb_lines, article_title in zip(id_src, infobox_src,
-                                                       nb_lines_src,
-                                                       article_title_src):
+        infobox_file
+    ) as infobox_src, tf.io.gfile.GFile(
+        nb_lines_file
+    ) as nb_lines_src, tf.io.gfile.GFile(
+        sentences_file
+    ) as sentences_src, tf.io.gfile.GFile(
+        article_title_file
+    ) as article_title_src:
+      for id_, infobox, nb_lines, article_title in zip(
+          id_src, infobox_src, nb_lines_src, article_title_src
+      ):
         target_text = []
         for _ in range(int(nb_lines)):
           target_text.append(sentences_src.readline())
         yield id_, {
             'input_text': {
                 'table': _get_table(infobox),
-                'context': article_title
+                'context': article_title,
             },
-            'target_text': ''.join(target_text)
+            'target_text': ''.join(target_text),
         }
