@@ -1,5 +1,5 @@
 # coding=utf-8
-# Copyright 2021 The TensorFlow Datasets Authors.
+# Copyright 2022 The TensorFlow Datasets Authors.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -18,7 +18,6 @@
 import tempfile
 
 from tensorflow_datasets import testing
-import tensorflow_datasets.public_api as tfds
 from tensorflow_datasets.summarization import cnn_dailymail
 
 _STORY_FILE = b"""Some article.
@@ -26,7 +25,7 @@ This is some article text.
 
 @highlight
 
-highlight text
+highlight text.
 
 @highlight
 
@@ -46,26 +45,19 @@ class CnnDailymailTest(testing.DatasetBuilderTestCase):
       'dm_stories': '',
       'test_urls': 'all_test.txt',
       'train_urls': 'all_train.txt',
-      'val_urls': 'all_val.txt'
+      'val_urls': 'all_val.txt',
   }
 
   def test_get_art_abs(self):
     with tempfile.NamedTemporaryFile(delete=True) as f:
       f.write(_STORY_FILE)
       f.flush()
-      article, abstract = cnn_dailymail._get_art_abs(f.name,
-                                                     tfds.core.Version('1.0.0'))
+      article, abstract = cnn_dailymail._get_art_abs(f.name)
       self.assertEqual('Some article. This is some article text.', article)
-      # This is a bit weird, but the original code at
-      # https://github.com/abisee/cnn-dailymail/ adds space before period
-      # for abstracts and we retain this behavior.
-      self.assertEqual('highlight text . Highlight two . highlight Three .',
-                       abstract)
 
-      article, abstract = cnn_dailymail._get_art_abs(f.name,
-                                                     tfds.core.Version('2.0.0'))
-      self.assertEqual('highlight text .\nHighlight two .\nhighlight Three .',
-                       abstract)
+      self.assertEqual(
+          'highlight text.\nHighlight two.\nhighlight Three.', abstract
+      )
 
 
 if __name__ == '__main__':
