@@ -1,5 +1,5 @@
 # coding=utf-8
-# Copyright 2021 The TensorFlow Datasets Authors.
+# Copyright 2022 The TensorFlow Datasets Authors.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -29,7 +29,7 @@ class WikihowTest(testing.DatasetBuilderTestCase):
   DL_EXTRACT_RESULT = {
       "train": "all_train.txt",
       "test": "all_test.txt",
-      "validation": "all_validation.txt"
+      "validation": "all_validation.txt",
   }
 
 
