@@ -172,8 +172,8 @@ def test_max_values(mock_data):
     for ex in ds.take(50):
       assert tf.math.reduce_max(ex['label']).numpy() < 10
     # Test determinism (iterating twice should yield the same samples)
-    assert [ex['label'].numpy() for ex in ds.take(5)] == [1, 9, 2, 5, 3]
-    assert [ex['label'].numpy() for ex in ds.take(5)] == [1, 9, 2, 5, 3]
+    assert [ex['label'].numpy() for ex in ds.take(5)] == [8, 2, 9, 3, 1]
+    assert [ex['label'].numpy() for ex in ds.take(5)] == [8, 2, 9, 3, 1]
 
 
 def test_mock_data_auto(tmp_path):
@@ -206,7 +206,7 @@ def test_mock_data_use_files(tmp_path):
   with tfds.testing.mock_data(policy=tfds.testing.MockPolicy.USE_FILES):
     builder = tfds.builder('mnist')
     # Metadata should have been restored correctly.
-    assert list(builder.info.splits.keys()) == ['test', 'train']
+    assert builder.info.splits.keys() == {'test', 'train'}
 
     # Unknown split should raise error
     # Currently, this error is accidentally triggered by
