@@ -1,5 +1,5 @@
 # coding=utf-8
-# Copyright 2021 The TensorFlow Datasets Authors.
+# Copyright 2022 The TensorFlow Datasets Authors.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -26,9 +26,7 @@ class C4Test(testing.DatasetBuilderTestCase):
   DL_EXTRACT_RESULT = {
       "wet_path_urls": ["wet_urls.txt"],
       "wet_files": ["cc_0.warc.wet.gz", "cc_1.warc.wet.gz"],
-      "badwords": {
-          "en": "badwords.txt"
-      },
+      "badwords": {"en": "badwords.txt"},
   }
   SPLITS = {
       "train": 2,
