@@ -71,44 +71,32 @@ the correct citation for each contained dataset."
 _URL_BASE = 'https://s3.us-east-2.amazonaws.com/mrqa/release/v2'
 _URLs = {
     # Train sub-datasets
-    'train+SQuAD':
-        f'{_URL_BASE}/train/SQuAD.jsonl.gz',
-    'train+NewsQA':
-        f'{_URL_BASE}/train/NewsQA.jsonl.gz',
-    'train+TriviaQA':
-        f'{_URL_BASE}/train/TriviaQA-web.jsonl.gz',
-    'train+SearchQA':
-        f'{_URL_BASE}/train/SearchQA.jsonl.gz',
-    'train+HotpotQA':
-        f'{_URL_BASE}/train/HotpotQA.jsonl.gz',
-    'train+NaturalQuestions':
-        f'{_URL_BASE}/train/NaturalQuestionsShort.jsonl.gz',
+    'train+SQuAD': f'{_URL_BASE}/train/SQuAD.jsonl.gz',
+    'train+NewsQA': f'{_URL_BASE}/train/NewsQA.jsonl.gz',
+    'train+TriviaQA': f'{_URL_BASE}/train/TriviaQA-web.jsonl.gz',
+    'train+SearchQA': f'{_URL_BASE}/train/SearchQA.jsonl.gz',
+    'train+HotpotQA': f'{_URL_BASE}/train/HotpotQA.jsonl.gz',
+    'train+NaturalQuestions': (
+        f'{_URL_BASE}/train/NaturalQuestionsShort.jsonl.gz'
+    ),
     # Validation sub-datasets
-    'validation+SQuAD':
-        f'{_URL_BASE}/dev/SQuAD.jsonl.gz',
-    'validation+NewsQA':
-        f'{_URL_BASE}/dev/NewsQA.jsonl.gz',
-    'validation+TriviaQA':
-        f'{_URL_BASE}/dev/TriviaQA-web.jsonl.gz',
-    'validation+SearchQA':
-        f'{_URL_BASE}/dev/SearchQA.jsonl.gz',
-    'validation+HotpotQA':
-        f'{_URL_BASE}/dev/HotpotQA.jsonl.gz',
-    'validation+NaturalQuestions':
-        f'{_URL_BASE}/dev/NaturalQuestionsShort.jsonl.gz',
+    'validation+SQuAD': f'{_URL_BASE}/dev/SQuAD.jsonl.gz',
+    'validation+NewsQA': f'{_URL_BASE}/dev/NewsQA.jsonl.gz',
+    'validation+TriviaQA': f'{_URL_BASE}/dev/TriviaQA-web.jsonl.gz',
+    'validation+SearchQA': f'{_URL_BASE}/dev/SearchQA.jsonl.gz',
+    'validation+HotpotQA': f'{_URL_BASE}/dev/HotpotQA.jsonl.gz',
+    'validation+NaturalQuestions': (
+        f'{_URL_BASE}/dev/NaturalQuestionsShort.jsonl.gz'
+    ),
     # Test sub-datasets
-    'test+BioASQ':
-        'http://participants-area.bioasq.org/MRQA2019/',  # BioASQ.jsonl.gz
-    'test+DROP':
-        f'{_URL_BASE}/dev/DROP.jsonl.gz',
-    'test+DuoRC':
-        f'{_URL_BASE}/dev/DuoRC.ParaphraseRC.jsonl.gz',
-    'test+RACE':
-        f'{_URL_BASE}/dev/RACE.jsonl.gz',
-    'test+RelationExtraction':
-        f'{_URL_BASE}/dev/RelationExtraction.jsonl.gz',
-    'test+TextbookQA':
-        f'{_URL_BASE}/dev/TextbookQA.jsonl.gz',
+    'test+BioASQ': (
+        'http://participants-area.bioasq.org/MRQA2019/'
+    ),  # BioASQ.jsonl.gz
+    'test+DROP': f'{_URL_BASE}/dev/DROP.jsonl.gz',
+    'test+DuoRC': f'{_URL_BASE}/dev/DuoRC.ParaphraseRC.jsonl.gz',
+    'test+RACE': f'{_URL_BASE}/dev/RACE.jsonl.gz',
+    'test+RelationExtraction': f'{_URL_BASE}/dev/RelationExtraction.jsonl.gz',
+    'test+TextbookQA': f'{_URL_BASE}/dev/TextbookQA.jsonl.gz',
 }
 
 
@@ -139,57 +127,49 @@ class MRQA(tfds.core.GeneratorBasedBuilder):
       '1.0.0': 'Initial release.',
   }
   DEFAULT_FEATURES = tfds.features.FeaturesDict({
-      'subset':
-          np.str_,
-      'context':
-          np.str_,
-      'context_tokens':
-          tfds.features.Sequence({
-              'tokens': np.str_,
-              'offsets': np.int32,
+      'subset': np.str_,
+      'context': np.str_,
+      'context_tokens': tfds.features.Sequence({
+          'tokens': np.str_,
+          'offsets': np.int32,
+      }),
+      'qid': np.str_,
+      'question': np.str_,
+      'question_tokens': tfds.features.Sequence({
+          'tokens': np.str_,
+          'offsets': np.int32,
+      }),
+      'detected_answers': tfds.features.Sequence({
+          'text': np.str_,
+          'char_spans': tfds.features.Sequence({
+              'start': np.int32,
+              'end': np.int32,
           }),
-      'qid':
-          np.str_,
-      'question':
-          np.str_,
-      'question_tokens':
-          tfds.features.Sequence({
-              'tokens': np.str_,
-              'offsets': np.int32,
+          'token_spans': tfds.features.Sequence({
+              'start': np.int32,
+              'end': np.int32,
           }),
-      'detected_answers':
-          tfds.features.Sequence({
-              'text':
-                  np.str_,
-              'char_spans':
-                  tfds.features.Sequence({
-                      'start': np.int32,
-                      'end': np.int32,
-                  }),
-              'token_spans':
-                  tfds.features.Sequence({
-                      'start': np.int32,
-                      'end': np.int32,
-                  }),
-          }),
-      'answers':
-          tfds.features.Sequence(np.str_),
+      }),
+      'answers': tfds.features.Sequence(np.str_),
   })
   BUILDER_CONFIGS = [
       MRQAConfig(
           name='squad',
-          description=textwrap.dedent("""\
+          description=textwrap.dedent(
+              """\
           The SQuAD (Stanford Question Answering Dataset) dataset is used as the
           basis for the shared task format. Crowdworkers are shown paragraphs
           from Wikipedia and are asked to write questions with extractive
           answers.
-          """),
+          """
+          ),
           features=DEFAULT_FEATURES,
           data_urls={
               'train': _URLs['train+SQuAD'],
               'validation': _URLs['validation+SQuAD'],
           },
-          citation=textwrap.dedent("""\
+          citation=textwrap.dedent(
+              """\
           @inproceedings{rajpurkar-etal-2016-squad,
               title = "{SQ}u{AD}: 100,000+ Questions for Machine Comprehension of Text",
               author = "Rajpurkar, Pranav  and
@@ -205,22 +185,27 @@ class MRQA(tfds.core.GeneratorBasedBuilder):
               doi = "10.18653/v1/D16-1264",
               pages = "2383--2392",
           }
-          """)),
+          """
+          ),
+      ),
       MRQAConfig(
           name='news_qa',
-          description=textwrap.dedent("""\
+          description=textwrap.dedent(
+              """\
           Two sets of crowdworkers ask and answer questions based on CNN news
           articles. The “questioners” see only the article’s headline and
           summary while the “answerers” see the full article. Questions that
           have no answer or are flagged in the dataset to be without annotator
           agreement are discarded.
-          """),
+          """
+          ),
           features=DEFAULT_FEATURES,
           data_urls={
               'train': _URLs['train+NewsQA'],
               'validation': _URLs['validation+NewsQA'],
           },
-          citation=textwrap.dedent("""\
+          citation=textwrap.dedent(
+              """\
           @inproceedings{trischler-etal-2017-newsqa,
               title = "{N}ews{QA}: A Machine Comprehension Dataset",
               author = "Trischler, Adam  and
@@ -239,20 +224,25 @@ class MRQA(tfds.core.GeneratorBasedBuilder):
               doi = "10.18653/v1/W17-2623",
               pages = "191--200",
           }
-      #     """)),
+      #     """
+          ),
+      ),
       MRQAConfig(
           name='trivia_qa',
-          description=textwrap.dedent("""\
+          description=textwrap.dedent(
+              """\
           Question and answer pairs are sourced from trivia and quiz-league
           websites. The web version of TriviaQA, where the contexts are
           retrieved from the results of a Bing search query, is used.
-          """),
+          """
+          ),
           features=DEFAULT_FEATURES,
           data_urls={
               'train': _URLs['train+TriviaQA'],
               'validation': _URLs['validation+TriviaQA'],
           },
-          citation=textwrap.dedent("""\
+          citation=textwrap.dedent(
+              """\
           @inproceedings{joshi-etal-2017-triviaqa,
               title = "{T}rivia{QA}: A Large Scale Distantly Supervised Challenge Dataset for Reading Comprehension",
               author = "Joshi, Mandar  and
@@ -268,42 +258,52 @@ class MRQA(tfds.core.GeneratorBasedBuilder):
               doi = "10.18653/v1/P17-1147",
               pages = "1601--1611",
           }
-          """)),
+          """
+          ),
+      ),
       MRQAConfig(
           name='search_qa',
-          description=textwrap.dedent("""\
+          description=textwrap.dedent(
+              """\
           Question and answer pairs are sourced from the Jeopardy! TV show. The
           contexts are composed of retrieved snippets from a Google search
           query.
-          """),
+          """
+          ),
           features=DEFAULT_FEATURES,
           data_urls={
               'train': _URLs['train+SearchQA'],
               'validation': _URLs['validation+SearchQA'],
           },
-          citation=textwrap.dedent("""\
+          citation=textwrap.dedent(
+              """\
           @article{dunn2017searchqa,
               title={Searchqa: A new q\&a dataset augmented with context from a search engine},
               author={Dunn, Matthew and Sagun, Levent and Higgins, Mike and Guney, V Ugur and Cirik, Volkan and Cho, Kyunghyun},
               journal={arXiv preprint arXiv:1704.05179},
               year={2017}
           }
-          """)),
+          """
+          ),
+      ),
       MRQAConfig(
           name='hotpot_qa',
-          description=textwrap.dedent("""\
+          description=textwrap.dedent(
+              """\
           Crowdworkers are shown two entity-linked paragraphs from Wikipedia and
           are asked to write and answer questions that require multi-hop
           reasoning to solve. In the original setting, these paragraphs are
           mixed with additional distractor paragraphs to make inference harder.
           Here, the distractor paragraphs are not included.
-          """),
+          """
+          ),
           features=DEFAULT_FEATURES,
           data_urls={
               'train': _URLs['train+HotpotQA'],
               'validation': _URLs['validation+HotpotQA'],
           },
-          citation=textwrap.dedent("""\
+          citation=textwrap.dedent(
+              """\
           @inproceedings{yang-etal-2018-hotpotqa,
               title = "{H}otpot{QA}: A Dataset for Diverse, Explainable Multi-hop Question Answering",
               author = "Yang, Zhilin  and
@@ -322,10 +322,13 @@ class MRQA(tfds.core.GeneratorBasedBuilder):
               doi = "10.18653/v1/D18-1259",
               pages = "2369--2380",
           }
-          """)),
+          """
+          ),
+      ),
       MRQAConfig(
           name='natural_questions',
-          description=textwrap.dedent("""\
+          description=textwrap.dedent(
+              """\
           Questions are collected from information-seeking queries to the Google
           search engine by real users under natural conditions. Answers to the
           questions are annotated in a retrieved Wikipedia page by crowdworkers.
@@ -335,13 +338,15 @@ class MRQA(tfds.core.GeneratorBasedBuilder):
           bounding box that comprise the actual answer (Short Answer). Only the
           examples that have short answers are used, and the long answer is used
           as the context.
-          """),
+          """
+          ),
           features=DEFAULT_FEATURES,
           data_urls={
               'train': _URLs['train+NaturalQuestions'],
               'validation': _URLs['validation+NaturalQuestions'],
           },
-          citation=textwrap.dedent("""\
+          citation=textwrap.dedent(
+              """\
           @article{kwiatkowski-etal-2019-natural,
               title = "Natural Questions: A Benchmark for Question Answering Research",
               author = "Kwiatkowski, Tom  and
@@ -371,10 +376,13 @@ class MRQA(tfds.core.GeneratorBasedBuilder):
               doi = "10.1162/tacl_a_00276",
               pages = "452--466",
           }
-          """)),
+          """
+          ),
+      ),
       MRQAConfig(
           name='bio_asq',
-          description=textwrap.dedent("""\
+          description=textwrap.dedent(
+              """\
           BioASQ, a challenge on large-scale biomedical semantic indexing and
           question answering, contains question and answer pairs that are
           created by domain experts. They are then manually linked to multiple
@@ -383,12 +391,14 @@ class MRQA(tfds.core.GeneratorBasedBuilder):
           single question can be linked to multiple, independent articles to
           create multiple QA-context pairs). Abstracts that do not exactly
           contain the answer are discarded.
-          """),
+          """
+          ),
           features=DEFAULT_FEATURES,
           data_urls={
               'test': _URLs['test+BioASQ'],
           },
-          citation=textwrap.dedent("""\
+          citation=textwrap.dedent(
+              """\
           @article{tsatsaronis2015overview,
               title={An overview of the BIOASQ large-scale biomedical semantic indexing and question answering competition},
               author={Tsatsaronis, George and Balikas, Georgios and Malakasiotis, Prodromos and Partalas, Ioannis and Zschunke, Matthias and Alvers, Michael R and Weissenborn, Dirk and Krithara, Anastasia and Petridis, Sergios and Polychronopoulos, Dimitris and others},
@@ -399,22 +409,27 @@ class MRQA(tfds.core.GeneratorBasedBuilder):
               year={2015},
               publisher={Springer}
           }
-          """)),
+          """
+          ),
+      ),
       MRQAConfig(
           name='drop',
-          description=textwrap.dedent("""\
+          description=textwrap.dedent(
+              """\
           DROP (Discrete Reasoning Over the content of Paragraphs) examples were
           collected similarly to SQuAD, where crowdworkers are asked to create
           question-answer pairs from Wikipedia paragraphs. The questions focus
           on quantitative reasoning, and the original dataset contains
           non-extractive numeric answers as well as extractive text answers. The
           set of questions that are extractive is used.
-          """),
+          """
+          ),
           features=DEFAULT_FEATURES,
           data_urls={
               'test': _URLs['test+DROP'],
           },
-          citation=textwrap.dedent("""\
+          citation=textwrap.dedent(
+              """\
           @inproceedings{dua-etal-2019-drop,
               title = "{DROP}: A Reading Comprehension Benchmark Requiring Discrete Reasoning Over Paragraphs",
               author = "Dua, Dheeru  and
@@ -432,10 +447,13 @@ class MRQA(tfds.core.GeneratorBasedBuilder):
               doi = "10.18653/v1/N19-1246",
               pages = "2368--2378",
           }
-          """)),
+          """
+          ),
+      ),
       MRQAConfig(
           name='duo_rc',
-          description=textwrap.dedent("""\
+          description=textwrap.dedent(
+              """\
           The ParaphraseRC split of the DuoRC dataset is used. In this setting,
           two different plot summaries of the same movie are collected—one from
           Wikipedia and the other from IMDb. Two different sets of crowdworkers
@@ -443,12 +461,14 @@ class MRQA(tfds.core.GeneratorBasedBuilder):
           are shown only the Wikipedia page, and the “answerers” are shown only
           the IMDb page. Questions that are marked as unanswerable are
           discarded.
-          """),
+          """
+          ),
           features=DEFAULT_FEATURES,
           data_urls={
               'test': _URLs['test+DuoRC'],
           },
-          citation=textwrap.dedent("""\
+          citation=textwrap.dedent(
+              """\
           @inproceedings{saha-etal-2018-duorc,
               title = "{D}uo{RC}: Towards Complex Language Understanding with Paraphrased Reading Comprehension",
               author = "Saha, Amrita  and
@@ -464,21 +484,26 @@ class MRQA(tfds.core.GeneratorBasedBuilder):
               doi = "10.18653/v1/P18-1156",
               pages = "1683--1693",
           }
-          """)),
+          """
+          ),
+      ),
       MRQAConfig(
           name='race',
-          description=textwrap.dedent("""\
+          description=textwrap.dedent(
+              """\
           ReAding Comprehension Dataset From Examinations (RACE) is collected
           from English reading comprehension exams for middle and high school
           Chinese students. The high school split (which is more challenging)
           is used and also the implicit “fill in the blank” style questions
           (which are unnatural for this task) are filtered out.
-          """),
+          """
+          ),
           features=DEFAULT_FEATURES,
           data_urls={
               'test': _URLs['test+RACE'],
           },
-          citation=textwrap.dedent("""\
+          citation=textwrap.dedent(
+              """\
           @inproceedings{lai-etal-2017-race,
               title = "{RACE}: Large-scale {R}e{A}ding Comprehension Dataset From Examinations",
               author = "Lai, Guokun  and
@@ -495,10 +520,13 @@ class MRQA(tfds.core.GeneratorBasedBuilder):
               doi = "10.18653/v1/D17-1082",
               pages = "785--794",
           }
-          """)),
+          """
+          ),
+      ),
       MRQAConfig(
           name='relation_extraction',
-          description=textwrap.dedent("""\
+          description=textwrap.dedent(
+              """\
           Given a slot-filling dataset, relations among entities are
           systematically transformed into questionanswer pairs using templates.
           For example, the educated_at(x, y) relationship between two entities x
@@ -507,12 +535,14 @@ class MRQA(tfds.core.GeneratorBasedBuilder):
           relation are collected. The dataset’s zeroshot benchmark split
           (generalization to unseen relations) is used, and only the positive
           examples are kept.
-          """),
+          """
+          ),
           features=DEFAULT_FEATURES,
           data_urls={
               'test': _URLs['test+RelationExtraction'],
           },
-          citation=textwrap.dedent("""\
+          citation=textwrap.dedent(
+              """\
           @inproceedings{levy-etal-2017-zero,
               title = "Zero-Shot Relation Extraction via Reading Comprehension",
               author = "Levy, Omer  and
@@ -528,20 +558,25 @@ class MRQA(tfds.core.GeneratorBasedBuilder):
               doi = "10.18653/v1/K17-1034",
               pages = "333--342",
           }
-          """)),
+          """
+          ),
+      ),
       MRQAConfig(
           name='textbook_qa',
-          description=textwrap.dedent("""\
+          description=textwrap.dedent(
+              """\
           TextbookQA is collected from lessons from middle school Life Science,
           Earth Science, and Physical Science textbooks. Questions that are
           accompanied with a diagram, or that are “True or False” questions are
           not included.
-          """),
+          """
+          ),
           features=DEFAULT_FEATURES,
           data_urls={
               'test': _URLs['test+TextbookQA'],
           },
-          citation=textwrap.dedent("""\
+          citation=textwrap.dedent(
+              """\
           @inproceedings{kembhavi2017you,
               title={Are you smarter than a sixth grader? textbook question answering for multimodal machine comprehension},
               author={Kembhavi, Aniruddha and Seo, Minjoon and Schwenk, Dustin and Choi, Jonghyun and Farhadi, Ali and Hajishirzi, Hannaneh},
@@ -549,7 +584,9 @@ class MRQA(tfds.core.GeneratorBasedBuilder):
               pages={4999--5007},
               year={2017}
           }
-          """)),
+          """
+          ),
+      ),
   ]
 
   def _info(self) -> tfds.core.DatasetInfo:
@@ -569,23 +606,31 @@ class MRQA(tfds.core.GeneratorBasedBuilder):
     split_generators = {}
 
     if 'train' in self.builder_config.data_urls:
-      split_generators.update({
-          tfds.Split.TRAIN:
-              self._generate_examples(path=data_dir['train'], split='train'),
-      })
+      split_generators.update(
+          {
+              tfds.Split.TRAIN: self._generate_examples(
+                  path=data_dir['train'], split='train'
+              ),
+          }
+      )
 
     if 'validation' in self.builder_config.data_urls:
-      split_generators.update({
-          tfds.Split.VALIDATION:
-              self._generate_examples(
-                  path=data_dir['validation'], split='validation'),
-      })
+      split_generators.update(
+          {
+              tfds.Split.VALIDATION: self._generate_examples(
+                  path=data_dir['validation'], split='validation'
+              ),
+          }
+      )
 
     if 'test' in self.builder_config.data_urls:
-      split_generators.update({
-          tfds.Split.TEST:
-              self._generate_examples(path=data_dir['test'], split='test'),
-      })
+      split_generators.update(
+          {
+              tfds.Split.TEST: self._generate_examples(
+                  path=data_dir['test'], split='test'
+              ),
+          }
+      )
     return split_generators
 
   def _generate_examples(self, path, split):
@@ -597,30 +642,28 @@ class MRQA(tfds.core.GeneratorBasedBuilder):
       for row in f:
         paragraph = json.loads(row)
         context = paragraph['context'].strip()
-        context_tokens = [{
-            'tokens': t[0],
-            'offsets': t[1]
-        } for t in paragraph['context_tokens']]
+        context_tokens = [
+            {'tokens': t[0], 'offsets': t[1]}
+            for t in paragraph['context_tokens']
+        ]
         for qa in paragraph['qas']:
           qid = qa['qid']
           question = qa['question'].strip()
-          question_tokens = [{
-              'tokens': t[0],
-              'offsets': t[1]
-          } for t in qa['question_tokens']]
+          question_tokens = [
+              {'tokens': t[0], 'offsets': t[1]} for t in qa['question_tokens']
+          ]
           detected_answers = []
           for detect_ans in qa['detected_answers']:
             detected_answers.append({
-                'text':
-                    detect_ans['text'].strip(),
-                'char_spans': [{
-                    'start': t[0],
-                    'end': t[1]
-                } for t in detect_ans['char_spans']],
-                'token_spans': [{
-                    'start': t[0],
-                    'end': t[1]
-                } for t in detect_ans['token_spans']],
+                'text': detect_ans['text'].strip(),
+                'char_spans': [
+                    {'start': t[0], 'end': t[1]}
+                    for t in detect_ans['char_spans']
+                ],
+                'token_spans': [
+                    {'start': t[0], 'end': t[1]}
+                    for t in detect_ans['token_spans']
+                ],
             })
           answers = qa['answers']
           yield f'{split}+{subset}_{qid}', {
